@@ -29,8 +29,8 @@ AvailableGroups::AvailableGroups(DbEnv *dbenv, Servers *_servers, QWidget * p) :
 	groupDb = new Db(dbEnv, 0);
 	int ret;
 	if ((ret=groupDb->open(NULL, dbName, NULL, DB_BTREE, DB_CREATE | DB_THREAD, 0644)) != 0)
-			qDebug("Error opening database: %s", dbEnv->strerror(ret));
-	else qDebug("AvailableGroups database opened");
+		kdDebug() << "Error opening database: " <<  dbEnv->strerror(ret) << endl;
+	else kdDebug() << "AvailableGroups database opened\n";
 	updating=false;
 	m_view=0;
 	Num_Col = 1;
@@ -61,14 +61,14 @@ void AvailableGroups::loadGroups( )
 	(new QVBoxLayout(m_view))->setAutoAdd(true);
 	m_filterEdit=new KLineEdit(m_view);
 	m_groupList=new KListView(m_view);
-	m_groupList->addColumn("Newsgroup");
+	m_groupList->addColumn(i18n("Newsgroup"));
 // 	m_groupList->addColumn("Articles");
 	m_groupList->setAllColumnsShowFocus(true);
 	m_groupList->setSelectionMode(QListView::Single);
 	m_groupList->setRootIsDecorated(false);
 	m_groupList->setItemMargin(3);
 	m_groupList->setSorting(0);
-	m_groupList->setShowSortIndicator(false);
+	m_groupList->setShowSortIndicator(true);
 	connect(m_filterEdit, SIGNAL(returnPressed(const QString& )), this, SLOT(slotActivateFilter(const QString& )));
 	
 	Servers::iterator it;
@@ -91,7 +91,8 @@ void AvailableGroups::loadGroups( )
 	
 	while ((ret=cursor->get(key, data, DB_NEXT)) != DB_NOTFOUND) {
 		g=new Group((char*)data->get_data());
-		item=new KListViewItem(m_groupList, g->name);
+// 		item=new KListViewItem(m_groupList, g->name);
+		item = new AGListViewItem(m_groupList, g->name);
 		groupsList.insert(g->name, g);
 // 		item=new QCheckListItem(m_groupList, g->name, QCheckListItem::CheckBox);
 // 		item->setText(1, g->description);
@@ -113,7 +114,7 @@ void AvailableGroups::loadGroups( )
 		
 		
 	}
-	qDebug("Groups: %d", count);
+	kdDebug() << "Groups: " << count << endl;
 	cursor->close();
 	delete key;
 	delete data;
@@ -286,7 +287,7 @@ void AvailableGroups::slotSubscribe( QListViewItem *item )
 	int ret;
 	
 	if ((ret=groupDb->get(NULL, key, data, 0)) != 0) {
-		qDebug("Error retrieving key");
+		kdDebug() << "Error retrieving key\n";
 		return;
 	}
 		
@@ -307,17 +308,17 @@ void AvailableGroups::slotSubscribe( QListViewItem *item )
 
 void AvailableGroups::slotActivateFilter( const QString &s )
 {
-	qDebug("Filtering by string: %s", (const char *) s);
+	kdDebug() << "Filtering by string: " << s << endl;
 	m_groupList->setEnabled(false);
 	m_filterEdit->setEnabled(false);
 	m_groupList->clear();
 	QDictIterator<Group> it(groupsList);
 	Servers::iterator sit;
-	KListViewItem *item;
+	AGListViewItem *item;
 // 	int Num_Col=1;
 	while(it.current()) {
 		if (it.currentKey().find(s, 0, false) != -1) {
-			item=new KListViewItem(m_groupList, it.current()->name, it.current()->description);
+			item=new AGListViewItem(m_groupList, it.current()->name);
 			int i =0;
 		
 			for (sit=servers->begin(); sit != servers->end(); ++sit) {
@@ -366,7 +367,7 @@ void AvailableGroups::slotUnsubscribe( QString gName)
 	key->set_size(gName.length());
 	int ret=groupDb->get(NULL, key, data, 0);
 	if (ret != 0) {
-		qDebug("Error retrieving group: %d", ret);
+		kdDebug() << "Error retrieving group: " << ret << endl;
 		return;
 	}
 	
@@ -378,7 +379,7 @@ void AvailableGroups::slotUnsubscribe( QString gName)
 	delete p;
 	ret=groupDb->put(NULL, key, data, 0);
 	if (ret != 0)
-		qDebug("Error saving group: %d", ret);
+		kdDebug() << "Error saving group: " << ret << endl;
 	else groupDb->sync(0);
 	
 	
@@ -406,9 +407,9 @@ void AvailableGroups::slotDeleteServer( int serverId)
 		if (g->serverPresence.isEmpty()) {
 			ret=cursor->del(0);
 			if (ret != 0)
-				qDebug("Cannot delete group record!");
+				kdDebug() << "Cannot delete group record\n";
 		} else if ((ret=cursor->put(&key, &data, DB_CURRENT)) !=0)
-			qDebug("cannot update group record! Error: %s", dbEnv->strerror(ret) );
+			kdDebug() << "Cannot update group record! Error: " <<  dbEnv->strerror(ret)  << endl;
 		
 		delete p;
 		
@@ -425,7 +426,7 @@ void AvailableGroups::slotDeleteServer( int serverId)
 void AvailableGroups::slotSubscribed( Group * g)
 {
 	//Save the group as subscribed
-	qDebug("Ok, subscribed");
+	kdDebug() << "Ok, subscribed\n";
 	
 	Dbt *key=new Dbt;
 	Dbt *data=new Dbt;
@@ -457,7 +458,7 @@ void AvailableGroups::slotSubscribed( Group * g)
 	
 	int ret=groupDb->put(NULL, key, data, 0);
 	if (ret != 0)
-		qDebug("Error saving group");
+		kdDebug() << "Error saving group\n";
 	else groupDb->sync(0);
 	
 	delete key;
@@ -466,3 +467,22 @@ void AvailableGroups::slotSubscribed( Group * g)
 		
 	
 }
+
+AGListViewItem::AGListViewItem( KListView * parent, QString ngName ) : KListViewItem(parent, ngName)
+{
+	
+}
+
+int AGListViewItem::compare( QListViewItem * i, int col, bool ascending ) const
+{
+	if (col == 0) 
+		return KListViewItem::compare(i, col, ascending);
+	else {
+		if ( text(col).toInt() < i->text(col).toInt())
+			return -1;
+		else if (text(col).toInt() > i->text(col).toInt())
+			return 1;
+		else return 0;
+	}
+		
+}
