@@ -30,6 +30,13 @@
 
 class AvailableGroups;
 
+class AGListViewItem : public KListViewItem
+{
+	public:
+	AGListViewItem(KListView * parent, QString ngName);
+	virtual int compare(QListViewItem *i, int col, bool ascending) const;
+	
+};
 
 
 class Group
