@@ -45,32 +45,55 @@ uchar* BinHeader::insert(QString s, uchar* p) {
 }
 
 
+uchar * BinHeader::retrieve( uchar *i, QString &s, uchar *limit )
+{
+	int strlen;
+//     int ssize=sizeof(strlen);
+
+	char *temp;
+	memcpy(&strlen, i, szInt);
+	if (i+szInt > limit)
+		throw new BHException(NULL);
+	else i+=szInt;
+	temp=new char[strlen+1];
+	if (i + strlen > limit)
+		throw new BHException(NULL);
+	else memcpy(temp, i, strlen);
+	
+	temp[strlen]='\0';
+	//double memcopy...save strings with NULL termination and do a "s=i"?
+	s=temp;
+	delete [] temp;
+	i+=strlen;
+	return i;
+
+}
+
 // Retrieves the string at current position in array i into the QString s
 // updates and returns i;
 
 uchar* BinHeader::retrieve(uchar* i,QString &s) 
 {
 
-    int strlen;
+	int strlen;
 //     int ssize=sizeof(strlen);
 
-    char *temp;
-    memcpy(&strlen, i, szInt);
+	char *temp;
+	memcpy(&strlen, i, szInt);
 
-    i+=szInt;
-    temp=new char[strlen+1];
-    memcpy(temp, i, strlen);
-    temp[strlen]='\0';
+	i+=szInt;
+	temp=new char[strlen+1];
+	memcpy(temp, i, strlen);
+	temp[strlen]='\0';
 	//double memcopy...save strings with NULL termination and do a "s=i"?
-    s=temp;
-    delete [] temp;
-    i+=strlen;
-    return i;
+	s=temp;
+	delete [] temp;
+	i+=strlen;
+	return i;
 
 
 
 }
-
 // Marshall the binHeader
 
 uchar *BinHeader::data() 
@@ -99,8 +122,14 @@ uchar *BinHeader::data()
 	
     i=insert(subj, i);
     i=insert(from,i);
-    i=insert(date,i);
 
+    //new  date format
+    //i=insert(date,i);
+    memcpy(i, &tDate, szInt);
+    i +=szInt;
+
+    
+    
     //copy fixed length fields...no big deal
     
 
@@ -217,21 +246,30 @@ uchar *BinHeader::data()
     return p;
 }
 
+
+
+
 //create binheader, unmarshalling DB data
 
-BinHeader::BinHeader(uchar *p, int version) 
+BinHeader::BinHeader(uchar *p, int version, int memSize) 
 {
 
-
-    uchar *pi =&p[0];
+	//This will be SLOW!!!
+	uchar *l= p + memSize;
+	uchar *pi =&p[0];
+	
 // 	int szInt=sizeof(int);
 	uint  part, serverNumItems, serverId, artNum;
 	//BEGIN serverLowest code
 	if (version >= 3) {
+
 		//Reload serverId, <lowest article number>
 		int serverLowestItems;
 		memcpy(&serverLowestItems, pi, szInt);
 		pi+=szInt;
+		if (pi + 2*szInt*serverLowestItems > l)
+			throw new BHException(NULL);
+		
 		for (int i = 0; i < serverLowestItems; i++) {
 			memcpy(&serverId, pi, szInt);
 			pi+=szInt;
@@ -244,29 +282,48 @@ BinHeader::BinHeader(uchar *p, int version)
 
     // Variable-lenght fields
 
-    pi=retrieve(pi,subj);
-    pi=retrieve(pi,from);
-    pi=retrieve(pi,date);
+	pi=retrieve(pi,subj);
+	pi=retrieve(pi,from);
+    
+	if (version < 6) {
+		pi=retrieve(pi,date);
+	} else {
+		memcpy(&tDate, pi, szInt);
+		if (pi + szInt > l)
+			throw new BHException(subj);
+		else pi+=szInt;
+		//Maybe is more practical to use:
+// 		if ( (pi+=szInt) > l)
+// 			throw new BHException();
+	}
 
 
     // Fixed-size fields:
 
-    memcpy(&numParts, pi, szInt);
-    pi+=szInt;
-    memcpy(&missingParts, pi, szInt);
-    pi+=szInt;
-    memcpy(&status, pi, szInt);
-    pi+=szInt;
+	memcpy(&numParts, pi, szInt);
+	if ( (pi+=szInt) > l)
+		throw new BHException(subj);
+	memcpy(&missingParts, pi, szInt);
+	if ( (pi+=szInt) > l)
+		throw new BHException(subj);
+	memcpy(&status, pi, szInt);
+	if ( (pi+=szInt) > l)
+		throw new BHException(subj);
     //status
-    memcpy(&lines, pi, szInt);
-    pi+=szInt;
-    memcpy(&size, pi, szInt);
-    pi+=szInt;
+	memcpy(&lines, pi, szInt);
+	if ( (pi+=szInt) > l)
+		throw new BHException(subj);
+	memcpy(&size, pi, szInt);
+	if ( (pi+=szInt) > l)
+		throw new BHException(subj);
 	
 	uint serverPartItems, partNumItems;
 	if (version >= 4) {
 		memcpy(&serverPartItems, pi, szInt);
-		pi+=szInt;
+		if ( (pi+=szInt) > l)
+			throw new BHException(subj);
+		if ( (pi + 2*szInt*serverPartItems) > l)
+			throw new BHException(subj);
 		for (uint i =0; i< serverPartItems; i++) {
 	
 			memcpy(&serverId, pi, szInt);
@@ -279,7 +336,8 @@ BinHeader::BinHeader(uchar *p, int version)
 	}
 		
 	memcpy(&partNumItems, pi, szInt);
-	pi+=szInt;
+	if ( (pi+=szInt) > l)
+		throw new BHException(subj);
 
 
 	
@@ -290,12 +348,16 @@ BinHeader::BinHeader(uchar *p, int version)
 	for (uint i = 0; i < partNumItems; i++) {
 		// get the partid;
 		memcpy(&part, pi, szInt);
-		pi+=szInt;
+		if ( (pi+=szInt) > l)
+			throw new BHException(subj);
 		//get the number of items in the servernum map
 		memcpy(&serverNumItems, pi, szInt);
-		pi+=szInt;
+		if ( (pi+=szInt) > l)
+			throw new BHException(subj);
 		// now rebuild the servernum map
 		// 		partNum.insert(part);
+		if ( (pi + 2*szInt * serverNumItems) > l)
+			throw new BHException(subj);
 		for (uint j = 0; j < serverNumItems; j++) {
 			memcpy(&serverId, pi, szInt);
 			pi+=szInt;
@@ -306,16 +368,18 @@ BinHeader::BinHeader(uchar *p, int version)
 	}
 	
 	
-		//BEGIN partMid code
+	//BEGIN partMid code
 		
 	if (version >= 2) {
 		uint partMidItems;
 		memcpy(&partMidItems, pi, szInt);
-		pi+=szInt;
+		if ( (pi+=szInt) > l)
+			throw new BHException(subj);
 		QString mid;
 		for (uint i = 0; i < partMidItems; i++) {
 			memcpy(&part, pi, szInt);
-			pi+=szInt;
+			if ( (pi+=szInt) > l)
+				throw new BHException(subj);
 			pi = retrieve(pi, mid);
 			partMid[part]=mid;
 			
@@ -327,7 +391,10 @@ BinHeader::BinHeader(uchar *p, int version)
 	if (version < 4) {
 	
 		memcpy(&serverPartItems, pi, szInt);
-		pi+=szInt;
+		if ( (pi+=szInt) > l)
+			throw new BHException(subj);
+		if ( (pi + 2*szInt* serverPartItems) > l)
+			throw new BHException(subj);
 		for (uint i =0; i< serverPartItems; i++) {
 	
 			memcpy(&serverId, pi, szInt);
@@ -346,7 +413,10 @@ BinHeader::BinHeader(uchar *p, int version)
 	if (version >= 1) {
 // 		qDebug("Loading size into bh");
 		memcpy(&serverPartItems, pi, szInt);
-		pi+=szInt;
+		if ( (pi+=szInt) > l)
+			throw new BHException(subj);
+		if ( (pi + 2*szInt * serverPartItems) > l)
+			throw new BHException(subj);
 		for (uint i = 0; i < serverPartItems; i++) {
 			memcpy(&serverId, pi, szInt);
 			pi+=szInt;
@@ -359,6 +429,10 @@ BinHeader::BinHeader(uchar *p, int version)
 	
 }
 
+
+//Version 6 of headerdb
+
+
 BinHeader::BinHeader(uchar *p) 
 {
 	uchar *pi =&p[0];
@@ -380,10 +454,11 @@ BinHeader::BinHeader(uchar *p)
 
 	pi=retrieve(pi,subj);
 	pi=retrieve(pi,from);
-	pi=retrieve(pi,date);
+	//pi=retrieve(pi,date);
 
     // Fixed-size fields:
-
+	memcpy(&tDate, pi, szInt);
+	pi+=szInt;
 	memcpy(&numParts, pi, szInt);
 	pi+=szInt;
 	memcpy(&missingParts, pi, szInt);
@@ -497,7 +572,7 @@ uint BinHeader::getRecordSize( ) {
 	
 			
 			
-    return 12*szInt+subj.length()+from.length()+date.length()+serverPart.count()*(2*szInt)+partNumSize \
+    return 12*szInt+subj.length()+from.length()+serverPart.count()*(2*szInt)+partNumSize \
 			+ 2*(szInt*partSize.count()) + partMidSize + 2*szInt*serverLowest.count();
 }
 
@@ -820,6 +895,7 @@ void BinHeader::addHost( int part, int hostId )
 }
 
 
+
 /*
 BinHeader::~BinHeader( )
 {
