@@ -32,7 +32,7 @@
 struct SmallBinHeader {
 	QString subj;
 	QString from;
-	QString date;
+	uint tDate;
 	int missingParts;
 	int parts;
 	int size;
@@ -53,6 +53,18 @@ struct BinHeaderSize
 };
 
 
+class BHException
+{
+	private:
+		QString m_index;
+	public:
+		BHException(QString i) {m_index = i;}
+		QString index() {return m_index;}
+		
+};
+
+
+
 typedef QMap<int, ServerNumMap> PartNumMap; //Hold <part, <serverid, articlenum>>
 typedef QMap <int, int> ServerPartMap; //Holds <serverid, number-of-parts-on-server>
 typedef QMap <int, QString> PartMid;
@@ -72,6 +84,7 @@ class BinHeader {
 		QString subj;
 		QString from;
 		QString date;
+		uint tDate;
 		uint numParts;
 		uint missingParts;
 		uint status;
@@ -82,21 +95,21 @@ class BinHeader {
 		ServerPartMap serverPart; //Useful for speeding loading of headers...
 		QMap<uint,uint> partSize; //part#, part Size
 		QMap<int, int> serverLowest; 
-
+		uchar* retrieve(uchar*,QString&, uchar *limit);
+		uchar* retrieve(uchar*, QString&);
 		ServerNumMap::iterator snmit;
 		ServerPartMap::iterator spmit;
 		uchar* insert(QString, uchar*);
-    	uchar* retrieve(uchar*,QString&);
 		PartNumMap::iterator pnmit;
 		
 	public:
-		enum status {bh_downloaded, bh_new, bh_read, bh_queued};
+		enum status {bh_downloaded, bh_new, bh_read, bh_queued, bh_downloading};
 		
 		enum Expire_Code {Delete_Read, Delete_Unread, No_Delete, No_Change };
 		enum Add_Code { Duplicate_Part, New_Part, Unread_Status };
-		void setSubj(QString s) {subj=s;};
-		void setFrom(QString s) {from=s;};
-		void setDate(QString s) {date=s;};
+		void setSubj(QString s) {subj=s;}
+		void setFrom(QString s) {from=s;}
+		void setDate(uint u) { tDate = u; }
 		void setStatus(uint s) {status=s;};
 		void setNumParts(int i) {numParts=missingParts=i;};
 		bool addPart(int, Header*);
@@ -108,7 +121,7 @@ class BinHeader {
 		bool isCompleted();
 		QString getSubj() {return subj;};
 		QString getFrom() {return from;};
-		QString getDate() {return date;};
+		uint getDate() {return tDate;};
 		inline int getSize() {return size;};
 		inline int getLines() {return lines;};
 		inline int getParts() {return numParts;};
@@ -116,7 +129,7 @@ class BinHeader {
 		inline int getStatus () {return status;};
 		inline void setStatus(int s) {status=s;};
 		BinHeader();
-		BinHeader(uchar*, int version); //for migration/verification
+		BinHeader(uchar*, int version, int memSize); //for migration/verification
 		BinHeader(uchar*);	//for "normal" use
 // 		~BinHeader();
 		uchar *data();
