@@ -56,6 +56,7 @@ void Configuration::read( )
 	conf->setGroup("View");
 	activateTab=conf->readBoolEntry("activateTab", true);
 	singleViewTab=conf->readBoolEntry("singleView", false);
+	showStatusBar=conf->readBoolEntry("showStatusBar", true);
 	dViewed=conf->readNumEntry("deleteViewed", Configuration::Ask);
 	
 	
@@ -68,9 +69,15 @@ void Configuration::read( )
 	markOpt = conf->readNumEntry("headerclose", Configuration::Ask);
 	
 	alwaysDoubleClick = conf->readBoolEntry("alwaysdoubleclick", false);
+	rememberSort = conf->readBoolEntry("remembersort", false);
+	rememberOrder = conf->readBoolEntry("rememberorder", false);
+	rememberWidth = conf->readBoolEntry("rememberwidth", false);
 	
 	keepListSettings = conf->readBoolEntry("keeplistsettings", false);
 	
+	
+		
+	
 
 }
 
@@ -92,6 +99,7 @@ void Configuration::write( ) const
 	conf->setGroup("View");
 	conf->writeEntry("activateTab", activateTab);
 	conf->writeEntry("singleView", singleViewTab);
+	conf->writeEntry("showStatusBar", showStatusBar);
 	conf->writeEntry("deleteViewed", dViewed);
 
 	
@@ -101,6 +109,9 @@ void Configuration::write( ) const
 	conf->writeEntry("showdetails", showDetails);
 	conf->writeEntry("showdate", showDate);
 	conf->writeEntry("allowexpansion", allowExpansion);
+	conf->writeEntry("remembersort", rememberSort);
+	conf->writeEntry("rememberorder", rememberOrder);
+	conf->writeEntry("rememberwidth", rememberWidth);
 	
 	conf->writeEntry("alwaysdoubleclick", alwaysDoubleClick);
 	conf->writeEntry("keeplistsettings", keepListSettings);
