@@ -34,8 +34,8 @@
 #define KEYMEM_SIZE 10000
 #define DATAMEM_SIZE 10000
 
-#define GROUPDB_VERSION 4
-#define HEADERDB_VERSION 5
+#define GROUPDB_VERSION 5
+#define HEADERDB_VERSION 6
 #define AVAILABLEGROUPSDB_VERSION 1
 #define SERVERDB_VERSION 1
 #define INDEXDB_VERSION 0
@@ -98,7 +98,7 @@ class Configuration {
 		int dViewed;
 		bool singleViewTab;
 		bool activateTab;
-		
+		bool showStatusBar;
 
 		//HeaderList options
 		bool showFrom;
@@ -107,6 +107,14 @@ class Configuration {
 		bool allowExpansion;
 		bool alwaysDoubleClick;
 		bool keepListSettings;
+		//remember sort column
+		bool rememberSort;
+		//remember order of columns
+		bool rememberOrder;
+		
+		//don't automatically resize columns (and remember the manual sizes)
+		bool rememberWidth;
+		
 		int markOpt;
 		
 		
