@@ -32,7 +32,7 @@
 GroupList::GroupList(QString _groupsDbName,  DbEnv *_dbenv, Servers *_servers, QWidget* parent, const char* name, WFlags fl)
 	: m_groupWidget(parent,name,fl),  dbenv(_dbenv),  servers(_servers), groupsDbName(_groupsDbName)
 {
-	setCaption("SubScribed groups");
+	setCaption(i18n("SubScribed groups"));
 	setIcon(KGlobal::iconLoader()->loadIcon("icon_newsgroup",KIcon::Small, KIcon::SizeSmall, false));
 	m_groupList->setColumnAlignment(Unread_Col, Qt::AlignRight);
 	m_groupList->setColumnAlignment(Total_Col, Qt::AlignRight);
@@ -104,7 +104,7 @@ void GroupList::loadGroups(DbEnv* dbe)
 	groupDb=new Db(dbenv,0);
 
 	if (groupDb->open(NULL, groupsDbName.latin1() , NULL, DB_BTREE, DB_CREATE | DB_THREAD , 0644) != 0)
-		qDebug("Error opening group db");
+		kdDebug() << "Error opening group db\n";
 	
 	char datamem[DATAMEM_SIZE];
 	char keymem[KEYMEM_SIZE];
@@ -203,7 +203,8 @@ void GroupList::slotAddGroup( Group* g)
 
 void GroupList::saveGroup( NewsGroup * ng )
 {
-	qDebug("Saving group");
+	//qDebug("Saving group");
+	kdDebug( ) << "Trying to save group\n";
 	char datamem[DATAMEM_SIZE];
 	char keymem[KEYMEM_SIZE];
 	
@@ -283,7 +284,7 @@ void GroupList::slotUpdateSubscribed( )
 		if (! it.current()->isUpdating()) {
 			it.current()->listItem->setEnabled(false);
 			emit updateNewsGroup(it.current(), 0);
-		} else qDebug("won't update group %s", (const char *) it.current()->ngName);
+		} else kdDebug() << "Won't update group " <<  it.current()->ngName << endl;
 		++it;
 	}
 	slotSelectionChanged();
@@ -364,7 +365,8 @@ void GroupList::slotZeroSelected( )
 	
 	while (it.current()) {
 		if (it.current()->rtti() != GITEM) {
-			qDebug("No group selected");
+			//qDebug("No group selected");
+			kdDebug() << "No group selected\n";
 			++it;
 			continue;
 		}
@@ -373,7 +375,7 @@ void GroupList::slotZeroSelected( )
 		uint *count=new uint;
 		
 		ng->getDb()->truncate(NULL, count, 0);
-		qDebug("Truncated %d record(s)", *count);
+		kdDebug() << "Truncated " << *count << " record(s)\n";
 		
 		ng->low.clear();
 		QMap<int, int>::iterator hit;
@@ -391,7 +393,8 @@ void GroupList::slotZeroSelected( )
 		
 // 		ng->listItem->setText(Unread_Col, QString::number(ng->totalArticles));
 // 		ng->listItem->setText(Total_Col, QString::number(ng->unreadArticles));
-		saveGroup(ng);
+		slotSaveSettings(ng,  ng->onlyUnread(), ng->onlyComplete());
+// 		saveGroup(ng);
 		delete count;
 		++it;
 		
@@ -586,6 +589,11 @@ void GroupList::slotGroupProperties( )
 	
 	
 	NewsGroup *ng=selected->getNg();
+	if( ng->isUpdating() ){
+		KMessageBox::error(this, i18n("Cannot show group properties while the group is updating"), i18n("Error"));
+		return;
+	}
+		
 	QStringList cats;
 	//Iterate on the categories and create a QStringList to load in the combobox...
 	QDictIterator<Category> git(categories);
@@ -749,6 +757,9 @@ void GroupList::slotCompactDbs( )
 	kpd->show();
 	int gCount=0;
 	int totalNewsgroups=groups.count();
+	QFile logFile(dbPath + '/' + "compact.log");
+	logFile.open(IO_WriteOnly | IO_Truncate);
+	QTextStream logStream(&logFile);
 	
 	while(it.current()) {
 		ng=it.current();
@@ -782,14 +793,39 @@ void GroupList::slotCompactDbs( )
 			memcpy(&storedSize, p + size-szInt, szInt);
 			if (storedSize != size) {
 				kdDebug() << "Error inside db: stored size different than actual key size!\n";
+				logStream << "Error inside db: stored size different than actual key size!\n";
 			} else {
-				totalArticles++;
-				bh = new BinHeader((uchar*)data.get_data());
-				if (bh->getStatus() == BinHeader::bh_new)
-					unreadArticles++;
-				delete bh;
-				if (newDb->put(0, &key, &data, 0) != 0)
-					qDebug("Error putting data into new db!");
+				
+				
+				try {
+					bh = new BinHeader((uchar*)data.get_data(), HEADERDB_VERSION, data.get_size());
+					
+					if (bh->getStatus() == BinHeader::bh_new)
+						unreadArticles++;
+					totalArticles++;
+					delete bh;
+// 					int transRet = transPut(newDb, &key, &data);
+					int transRet = newDb->put(0, &key, &data,0);
+					switch  (transRet) {
+						case DB_RUNRECOVERY:
+							KMessageBox::error(this, i18n("Unrecoverable error on db. Please restart KLibido"), i18n("Fatal error"));
+							exit (-1);
+							break;
+						case 0:
+							break;
+						default:
+							logStream << "Error inserting record into new db: " << transRet << endl;
+							kdDebug() << "Error inserting record into new db: " << dbenv->strerror(transRet) << endl;
+							break;
+					}
+				} catch (BHException *bhe) {
+					logStream << "Malformed record: ";
+					QString r;
+					if (bhe->index() == NULL)
+						r = " Unknown\n";
+					else r = bhe->index() + "\n";
+					logStream << r;
+				}				
 			}
 			
 			free(key.get_data());
@@ -843,6 +879,7 @@ void GroupList::slotCompactDbs( )
 		//Reassign newsgroup pointer
 		
 	}
+	logFile.close();
 	delete kpd;
 
 	
@@ -853,7 +890,8 @@ void GroupList::slotCompactDbs( )
 
 void GroupList::slotSaveSettings( NewsGroup *ng, bool unread, bool complete)
 {
-// 	qDebug("Saving group");
+	kdDebug( ) << "slotSaveSettings( )\n";
+	
 	ng->showOnlyUnread=unread;
 	ng->showOnlyComplete=complete;
 	ng->listItem->setText(Unread_Col, QString::number(ng->unreadArticles));
@@ -862,6 +900,7 @@ void GroupList::slotSaveSettings( NewsGroup *ng, bool unread, bool complete)
 // 	qDebug("Unread: %d", ng->onlyUnread());
 // 	qDebug("Complete: %d", ng->onlyComplete());
 	saveGroup(ng);
+	
 }
 
 void GroupList::updateCurrent( NewsGroup * ng )
