@@ -27,8 +27,16 @@
 #include <errno.h>
 #include <kprogress.h>
 #include <qregexp.h>
+#include <qstringlist.h>
+#include <qheader.h>
 
+static const char *fPatterns[] = { "^(.*)(\".*\")",
+								"^(.*)\\s-\\s(.*)$",
+								"\0"};
 
+static const char *cPatterns[] = {"Subject", "Parts", "KBytes", "Date", "From"};
+								
+								
 NewHeaderList::NewHeaderList(NewsGroup *_ng, Servers *_servers, QString caption, QWidget *parent): KMdiChildView (caption, parent), ng(_ng), servers(_servers) 
 {
 	showFrom=Config().showFrom;
@@ -44,11 +52,11 @@ NewHeaderList::NewHeaderList(NewsGroup *_ng, Servers *_servers, QString caption,
 	m_clearButton=new QToolButton(this);
 	m_clearButton->setIconSet(KGlobal::iconLoader()->loadIcon("locationbar_erase", KIcon::Small, 0, false));
 	QLabel *label=new QLabel(this);
-	label->setText("Filter by subject:");
+	label->setText(i18n("Filter by subject:"));
 	m_enterButton=new QToolButton(this);
 	m_enterButton->setIconSet(KGlobal::iconLoader()->loadIcon("key_enter", KIcon::Small, 0, false));
 	
-	regExpCheck = new QCheckBox("Regular expression", this);
+	regExpCheck = new QCheckBox(i18n("Regular expression"), this);
 	
 	
 	filterLayout->addWidget(m_clearButton);
@@ -63,20 +71,20 @@ NewHeaderList::NewHeaderList(NewsGroup *_ng, Servers *_servers, QString caption,
 	
 	m_headerList=new KListView(this);
 	layout->addWidget(m_headerList);
-	m_headerList->addColumn("Subject");
-	m_headerList->addColumn("Parts");
-	m_headerList->addColumn("KBytes");
+	m_headerList->addColumn(i18n(cPatterns[Subj_Col]));
+	m_headerList->addColumn(i18n(cPatterns[Parts_Col]));
+	m_headerList->addColumn(i18n(cPatterns[Bytes_Col]));
 // 	m_headerList->addColumn("Lines");
 	if (showFrom)
-		m_headerList->addColumn("From");
+		m_headerList->addColumn(i18n(cPatterns[From_Col]));
 	if (showDate)
-		m_headerList->addColumn("Date");
+		m_headerList->addColumn(i18n(cPatterns[Date_Col]));
 // 	m_headerList->addColumn("From");
 	m_headerList->setAllColumnsShowFocus(true);
 	m_headerList->setSelectionMode(QListView::Extended);
 	
 	m_headerList->setItemMargin(3);
-	m_headerList->setSorting(Subj_Col);
+// 	m_headerList->setSorting(Subj_Col);
 	m_headerList->setShowSortIndicator(true);
 	if (showDetails) {
 		Servers::iterator it;
@@ -86,8 +94,9 @@ NewHeaderList::NewHeaderList(NewsGroup *_ng, Servers *_servers, QString caption,
 	} else servers = NULL;
 	setIcon(KGlobal::iconLoader()->loadIcon("icon_newsgroup",KIcon::Small, KIcon::SizeSmall, false));
 	loadGroup(ng->getDb() );
-// 	m_loadGroup(ng->getDb());
-// 	connect(m_filterEdit, SIGNAL(returnPressed(const QString &)), this, SLOT(slotActivateFilter(const QString& )));
+	
+
+
 	connect(m_filterEdit, SIGNAL(returnPressed()), this, SLOT(slotEnterButtonClicked()));
 	connect(m_enterButton, SIGNAL(clicked()), this, SLOT(slotEnterButtonClicked()));
 	connect(m_headerList, SIGNAL(contextMenuRequested(QListViewItem *, const QPoint &, int)), this, SLOT(slotContextMenu(QListViewItem*, const QPoint& )));
@@ -97,12 +106,47 @@ NewHeaderList::NewHeaderList(NewsGroup *_ng, Servers *_servers, QString caption,
 		connect(m_headerList, SIGNAL(doubleClicked(QListViewItem* )), this, SLOT(slotItemExecuted()));
 	else connect(m_headerList, SIGNAL(executed(QListViewItem* )), this, SLOT(slotItemExecuted()));
 	
+	connect(m_headerList->header(), SIGNAL(indexChange(int, int, int)), this, SLOT(slotIndexChanged(int, int, int)));
+	connect(m_headerList->header(), SIGNAL(sizeChange(int, int, int)), this, SLOT(slotColSizeChanged(int, int, int)));
+	
+	
+	
+	//Reorder columns (this should be a macro)
+	
+	if (Config().rememberOrder) {
+		if (ng->getColIndex(Subj_Col) != -1)
+			m_headerList->header()->moveSection(Subj_Col, ng->getColIndex( Subj_Col));
+		if (ng->getColIndex(Parts_Col) != -1)
+			m_headerList->header()->moveSection(Parts_Col, ng->getColIndex( Parts_Col));
+		if (ng->getColIndex(Bytes_Col) != -1)
+			m_headerList->header()->moveSection(Bytes_Col, ng->getColIndex(Bytes_Col));
+// 		kdDebug() << "Date col index: " << ng->getColIndex(Date_Col) << endl;
+		if (showDate && ng->getColIndex(Date_Col) != -1)
+			m_headerList->header()->moveSection(Date_Col,  ng->getColIndex(Date_Col));
+		if (showFrom && ng->getColIndex(From_Col) != -1)
+			m_headerList->header()->moveSection(From_Col, ng->getColIndex( From_Col));
+			
+	}
+	
+	if( Config().rememberWidth ){
+		adjColSize(Subj_Col);
+		adjColSize(Parts_Col);
+		adjColSize( Bytes_Col);
+		if (showFrom)
+			adjColSize(From_Col);
+		if (showDate)
+			adjColSize(Date_Col);
+		
+	}
+	
+	
 	showOnlyNew=ng->onlyUnread();
 	showOnlyComplete=ng->onlyComplete();
 	if (showOnlyComplete || showOnlyNew)
 		filter(m_filterEdit->text());
 	m_headerList->setFocus();
 	
+	
 }
 
 
@@ -157,9 +201,11 @@ void NewHeaderList::loadGroup( Db * db )
 	QDateTime hDate;
 	QDateTime cDate = QDateTime::currentDateTime();
 	previous=QTime::currentTime();
+	
 	int deleteOlder = ng->getDeleteOlder();
 	
-	
+	QTime start = QTime::currentTime();
+	kdDebug() << "Loading started: " << start.toString() << endl;
 	while ((ret=cursor->get(binkey, bindata, DB_NEXT)) != DB_NOTFOUND) {
 
 #if DB_AT_LEAST(4,3)
@@ -200,7 +246,8 @@ void NewHeaderList::loadGroup( Db * db )
 				//Check deleteOlder
 				if (deleteOlder > 0) {
 					//check and, if needed, delete the header
-					hDate = QDateTime::fromString(sbh->date);
+					//hDate = QDateTime::fromString(sbh->date);
+					hDate.setTime_t(sbh->tDate);
 					if (hDate.daysTo(cDate) > deleteOlder ) {
 // 						qDebug("Current date: %s", (const char *) cDate.toString());
 						qDebug("Header date: %s", (const char *) hDate.toString());
@@ -239,13 +286,19 @@ void NewHeaderList::loadGroup( Db * db )
 	
 	
 	}
+	kdDebug() << "Loading finished. Seconds: " << start.secsTo(QTime::currentTime()) << endl;
 	kpd->progressBar()->setProgress(100);
 	
 // 	qDebug("Count: %d", count);
 	cursor->close();
-	emit sigSaveSettings(ng, showOnlyNew, showOnlyComplete);
+// 	emit sigSaveSettings(ng, showOnlyNew, showOnlyComplete);
 	m_headerList->setUpdatesEnabled(TRUE);
-	m_headerList->setSorting(0);
+	if (Config().rememberSort && ng->getSortColumn() != -1) {
+		m_headerList->setSorting(ng->getSortColumn(), ng->getSortOrder());
+	} else {
+		//Default sort
+	 	m_headerList->setSorting(Subj_Col);
+	}
 	
 	m_filterEdit->setEnabled(true);
 	delete [] binkeymem;
@@ -467,7 +520,8 @@ void NewHeaderList::slotDelSelected()
 // 	if (first)
 // 		m_headerList->ensureItemVisible(first);	
 	m_headerList->scrollBy(0, -(count*height));
-	m_headerList->adjustColumn(0);
+	if (!Config().rememberWidth)
+		m_headerList->adjustColumn(0);
 	emit updateFinished(ng);
 	
 }
@@ -576,7 +630,8 @@ void NewHeaderList::markSelectedAs( int what)
 // 	if (first)
 // 		m_headerList->ensureItemVisible(first);	
 	m_headerList->scrollBy(0, -(count*height));
-	m_headerList->adjustColumn(0);
+	if (!Config().rememberWidth)
+		m_headerList->adjustColumn(0);
 	emit updateFinished(ng);
 	
 	
@@ -696,7 +751,7 @@ void NewHeaderList::filter( const QString &s)
 		
 	m_headerList->setEnabled(true);
 	m_filterEdit->setEnabled(true);
-	m_headerList->adjustColumn(0);
+// 	m_headerList->adjustColumn(0);
 	
 }
 
@@ -805,6 +860,7 @@ void NewHeaderList::slotViewArticle( )
 
 void NewHeaderList::closeAndMark( )
 {
+	saveSettings();
 	QCloseEvent *e = new QCloseEvent();
 	ng->setView(NULL);
 	markGroupAsRead();
@@ -814,6 +870,7 @@ void NewHeaderList::closeAndMark( )
 
 void NewHeaderList::closeAndNoMark( )
 {
+	saveSettings();
 	QCloseEvent *e = new QCloseEvent();
 	ng->setView(NULL);
 	KMdiChildView::closeEvent(e);
@@ -825,14 +882,17 @@ void NewHeaderList::closeEvent( QCloseEvent * e )
 	
 	if (ng->isUpdating() || ng->unread() == 0 ) {
 		ng->setView(NULL);
+		saveSettings();
 		KMdiChildView::closeEvent(e);
 	}
 	else {
+		SortOrder so;
 		switch (Config().markOpt) {
 			case Configuration::Yes:
 				markGroupAsRead();
 			case Configuration::No:
-				ng->setView(NULL);
+				saveSettings();
+				ng->setView(NULL);				
 				KMdiChildView::closeEvent(e);
 				break;
 			case Configuration::Ask:
@@ -841,11 +901,17 @@ void NewHeaderList::closeEvent( QCloseEvent * e )
 					case KMessageBox::Yes:
 				//Mark all messages as read
 	// 				markAllAsRead( ng->getDb()  );
+						
 						markGroupAsRead();
 					
 					case KMessageBox::No:
 				//do nothing
+						saveSettings();
 						ng->setView(NULL);
+						ng->setSortColumn( m_headerList->sortColumn());
+						so = m_headerList->sortOrder();
+						ng->setSortOrder( so == Qt::Ascending ? true : false);
+						emit sigSaveSettings(ng, showOnlyNew, showOnlyComplete);
 						KMdiChildView::closeEvent(e);
 						break;
 					case KMessageBox::Cancel:
@@ -858,6 +924,8 @@ void NewHeaderList::closeEvent( QCloseEvent * e )
 		}
 		
 		
+		
+		
 			
 		
 		
@@ -1015,7 +1083,10 @@ SmallBinHeader * NewHeaderList::getSmallBinHeader( char * p )
 	i=retrieve(i, sbh->subj);
 // 	kdDebug() << "Subj: "<< sbh->subj << endl;
 	i=retrieve(i, sbh->from);
-	i=retrieve(i, sbh->date);
+	//i=retrieve(i, sbh->date);
+	
+	memcpy(&(sbh->tDate), i, szInt);
+	i+=szInt;
 	
 	memcpy(&(sbh->parts), i, szInt);
 	i+=szInt;
@@ -1045,6 +1116,7 @@ SmallBinHeader * NewHeaderList::getSmallBinHeader( char * p )
 	
 }
 
+
 void NewHeaderList::slotEnterButtonClicked( )
 {	
 	
@@ -1062,6 +1134,538 @@ void NewHeaderList::slotEnterButtonClicked( )
 	
 }
 
+void NewHeaderList::slotGroupArticles() 
+{
+	
+	
+	
+	
+}
+
+
+
+
+
+/**
+ *  Version 3: suppose that the items are sorted by from, then subject
+ */
+void NewHeaderList::slotGroupWithFrom()
+{
+	m_headerList->setRootIsDecorated(TRUE);
+	BHListViewItem *item=(BHListViewItem*)m_headerList->firstChild();
+	QTime startTime =QTime::currentTime();
+	BHListViewItem *curItem=0, *tempItem=0;
+// 	m_headerList->setSorting(From_Col);
+	//Compare indexes only - no fuzzy match between adjacent items
+// 	GListViewItem *dummyItem = new GListViewItem();
+	GListViewItem *gItem=0;
+	while (item) {
+		gItem = 0;
+		int matchCount = 0;
+// 		bool fromMatch;
+		QString from = item->getFrom();
+		curItem = (BHListViewItem*)item->nextSibling();
+		
+		while (curItem && curItem->getFrom() == from) {
+// 			qDebug("Trying to match with %s", curItem->getSubject().latin1());
+			qDebug("Examining %s", item->getSubject().latin1());
+// 			gItem = 0;
+			if (fuzzyMatch(item->getSubject(), curItem->getSubject()) >= 0.8) {
+// 				fromCount++;
+				//compare with all the items in the list...
+				
+				qDebug("Match: %s", curItem->getSubject().latin1());
+					//Found a match!
+					
+				matchCount++;
+				if (gItem) {
+					tempItem = (BHListViewItem*)curItem->nextSibling();	
+					m_headerList->takeItem(curItem);
+					gItem->addPart(curItem);
+					curItem=tempItem;
+					tempItem=0;
+					
+				} else {
+					//Create the GListViewItem
+					gItem = new GListViewItem(m_headerList, item, 0, 0);
+					tempItem = (BHListViewItem*) curItem->nextSibling();
+					m_headerList->takeItem(curItem);
+					gItem->addPart(curItem);
+					curItem = tempItem;
+					tempItem=0;
+					
+				}
+			} else {
+// 				tempItem = (BHListViewItem*) curItem->nextSibling();
+				qDebug("No Match with: %s", curItem->getSubject().latin1());
+				m_headerList->takeItem(item);
+				if (gItem) {
+				//Found a match, 
+					gItem->addPart(item);
+					itemIndex.insert(item->getSubject(), gItem);
+					gItem=0;
+					qDebug("ItemIndex: %s", item->getSubject().latin1());
+				} else {
+// 				qDebug("TempItems: %s", item->getSubject().latin1());
+					tempItems.insert(item->getSubject(), item);
+					qDebug("Tempitem: %s", item->getSubject().latin1());
+				}
+				item = curItem;
+				from = item->getFrom();
+				curItem = (BHListViewItem*)item->nextSibling();
+				
+			}
+			
+		} //while
+// 		qDebug("Posts from %s: %d", item->getFrom().latin1(), fromCount);
+		if (gItem) {
+			
+			tempItem = (BHListViewItem*) item->nextSibling();
+			m_headerList->takeItem(item);
+			
+			itemIndex.insert(item->getSubject(), gItem);
+			item = tempItem;
+			
+			
+		} else {
+			tempItem = (BHListViewItem*) item->nextSibling();
+			m_headerList->takeItem(item);
+			tempItems.insert(item->getSubject(), item);
+			item = tempItem;
+			
+		}
+		
+		//Scan!
+		qDebug("From: %s; tempItems: %d; indexItem: %d", from.latin1(), tempItems.count(), itemIndex.count());
+		QDictIterator<BHListViewItem> it(tempItems);
+		
+		while (it.current()) {
+			QDictIterator<GListViewItem> indexIt(itemIndex);
+			qDebug("Examining temp item: %s", it.currentKey().latin1());
+			while (indexIt.current()) {
+				if (fuzzyMatch(it.currentKey(), indexIt.currentKey()) >= 0.8 ) {
+					//Match! 
+					qDebug("Match with index item: %s", indexIt.currentKey().latin1());
+					indexIt.current()->addPart(it.current());
+					tempItems.remove(it.currentKey()); //it autoincrements
+					break;
+				} else ++indexIt;
+			}
+			//now try to match with the items in tempItems
+			// I *hate* alternate posts!
+			if (!indexIt.current()) {
+				//not found, try to match inside tempItems
+				QDictIterator<BHListViewItem> sit = it;
+				++sit;
+				gItem = 0;
+				while (sit.current()) {
+					if (fuzzyMatch(it.current()->getSubject(), sit.current()->getSubject()) >= 0.8) {
+						//match!
+						if (gItem) {
+							//add the part
+							gItem->addPart(sit.current());
+							tempItems.remove(sit.currentKey()); //sit autoincrements
+						} else {
+							//create and add the two parts
+							gItem = new GListViewItem(m_headerList, it.current(), 0, 0);
+							
+							gItem->addPart(sit.current());
+							tempItems.remove(sit.currentKey());
+							
+						}
+					} else ++sit;
+				}
+				if (gItem) {
+					//ok, item matched
+					gItem->addPart(it.current());
+					tempItems.remove(it.currentKey());
+					
+					
+				} else {
+					hiddenItems.insert(it.currentKey(), it.current());
+					tempItems.remove(it.currentKey());
+				}
+				
+			}
+	
+			
+			
+		}
+		
+		
+	
+		tempItems.clear();
+		itemIndex.clear();
+		//BEGIN DEBUG
+// 		break;
+		//END DEBUG
+	}
+	QTime endTime = QTime::currentTime();
+	
+	QDictIterator<BHListViewItem> it(hiddenItems);
+	qDebug("Items not categorized:");
+	while (it.current()) {
+		qDebug("%s", it.current()->getSubject().latin1());
+		++it;
+	}
+	qDebug("Time elapsed (s): %d", endTime.secsTo(startTime));
+}
+
+
+//version 2: try to create indexes...
+
+void NewHeaderList::slotGroupWithIndex( ) 
+{
+	m_headerList->setRootIsDecorated(TRUE);
+	BHListViewItem *item=(BHListViewItem*)m_headerList->firstChild();
+	QTime startTime =QTime::currentTime();
+	BHListViewItem *curItem=0;
+	//Compare indexes only - no fuzzy match between adjacent items
+// 	GListViewItem *dummyItem = new GListViewItem();
+	GListViewItem *gItem=0;
+	while (item) {
+		curItem=item;
+		item= (BHListViewItem*) item->nextSibling();
+		curItem->setExpandable(false);
+		m_headerList->takeItem(curItem);
+		QString index = makeIndex(curItem->getSubject());
+		qDebug("Examining index %s", index.latin1());
+		if (index != QString::null) {
+			if ((gItem = itemIndex[index]) != 0) {
+				//Already have an item, add the part
+				qDebug("New part for index: %s", index.latin1());
+				gItem->addPart(curItem);
+				
+				
+			} else {
+				//first post with this index, insert
+				qDebug("New item: %s", index.latin1());
+				gItem = new GListViewItem(m_headerList, curItem, 0, 0);
+				gItem->addPart(curItem);
+				itemIndex.insert(index, gItem);
+				
+			}
+		} else { //no filename found in post - discard it...
+			qDebug("No filename in subject: %s", curItem->getSubject().latin1());
+			hiddenItems.insert(curItem->getSubject(), curItem);
+		}
+		
+	}
+	QTime endTime = QTime::currentTime();
+	qDebug("Time elapsed (s): %d", endTime.secsTo(startTime));
+	QDictIterator<BHListViewItem> it(hiddenItems);
+	qDebug("Items not categorized:");
+	while (it.current()) {
+		qDebug("%s", it.current()->getSubject().latin1());
+		++it;
+	}
+}
+
+
+
+//fuzzy match only
+
+//Version 1: fuzzy match between items - works, but needs a lot of time
+void NewHeaderList::slotGroupMatchAdjacent( )
+{
+
+	QString rs1 = "^(.*)(\".*\")";
+	QString rs2 = "^(.*)\\s-\\s(.*)$";
+	QRegExp rx;
+// 	rx.setPattern(rs);
+	m_headerList->setRootIsDecorated(TRUE);
+	BHListViewItem *item=(BHListViewItem*)m_headerList->firstChild();
+	int pos;
+	//Try with "Distances" - match only with adiacent items (great locality of reference)
+	QTime startTime =QTime::currentTime();
+	BHListViewItem *nextItem;
+	BHListViewItem *tempItem;
+	int origarea;
+	float minratio = 2.0;
+	float ratio;
+	while (item) {
+		item->setExpandable(false);
+		QString subj = item->getSubject();
+		qDebug("Examining %s, area %d", (const char *) subj, area(subj));
+		origarea=area(subj);
+		rx.setPattern(rs1);
+		if ((pos=rx.searchRev(subj)) == -1) {
+			rx.setPattern(rs2);
+			pos = rx.searchRev(subj);
+		}
+		if (pos != -1)
+			qDebug("Filename: %s, index: %s", rx.cap(2).latin1(), rx.cap(1).latin1());
+		else qDebug("Filename not found in %s", subj.latin1());
+		nextItem = (BHListViewItem*)item->nextSibling();
+// 		qDebug("Comparing to %s", (const char *) item->getSubject());
+		GListViewItem *glv=0;
+		while ( nextItem && fuzzyMatch(subj, nextItem->getSubject()) >= 0.8 ) {
+			//Do something with the item here
+			nextItem->setExpandable(false);
+			ratio = ((float)area(nextItem->getSubject()))/float(origarea);
+			qDebug("Match: %s, area %d, ratio %f", (const char *)nextItem->getSubject(), area(nextItem->getSubject()), ratio);
+			if ( ratio < minratio)
+				minratio = ratio;
+			tempItem = (BHListViewItem*) nextItem->nextSibling();
+			m_headerList->takeItem(nextItem);
+			if (glv) {
+				glv->addPart(nextItem);
+			} else {
+				glv = new GListViewItem(m_headerList, item, 0, 0);
+// 				glv->addPart(item);
+				glv->addPart(nextItem);
+			}
+			nextItem = tempItem;
+			
+		}
+		tempItem = (BHListViewItem*) item->nextSibling();
+// 		qDebug("Taking away %s", (const char *) item->getSubject());
+		m_headerList->takeItem(item);
+// 		m_headerList->removeItem(item);
+		if (glv) {
+			glv->addPart(item);
+		} else hiddenItems.insert(item->getSubject(), item);
+		item = tempItem;
+	}
+	
+	qDebug("Minratio: %f", minratio);
+	//Try with "distances - match with ALL the items (complexity: N!)
+	qDebug("\nSecond run: full match on the remaining items\n");
+	QDictIterator<BHListViewItem> it (hiddenItems);
+	
+	while ( (item = it.current())) {
+		QString subj = item->getSubject();
+		qDebug("Examining %s", subj.latin1());
+		//First, scan all the Group items...
+		GListViewItem *glv = (GListViewItem*) m_headerList->firstChild();
+		while (glv) {
+			if (fuzzyMatch(subj, glv->getSubject()) >= 0.8) {
+				qDebug("Match: %s", (const char *) glv->getSubject());
+				hiddenItems.remove(it.currentKey());
+				glv->addPart(item);
+				//I don't need to increment the iterator (...)
+				break;
+			}
+			glv = (GListViewItem*) glv->nextSibling();
+		}
+		if (glv == 0) { //not found, scan the hidden items
+			QDictIterator<BHListViewItem> sit=it;
+			++sit;
+			nextItem = sit.current();
+			
+			while (nextItem) {
+				if (fuzzyMatch(subj, nextItem->getSubject()) >= 0.8) {
+					//found! 
+					qDebug("Match in hiddenItems: %s", (const char *) nextItem->getSubject());
+					if (glv) {
+						glv->addPart(nextItem);
+						//next line increments sit
+						hiddenItems.remove(sit.currentKey());
+						
+					} else {
+						
+						glv = new GListViewItem(m_headerList, item, 0, 0);
+						glv->addPart(nextItem);
+						glv->addPart(item);
+						hiddenItems.remove(sit.currentKey());
+						hiddenItems.remove(it.currentKey());
+					}
+					
+				} else ++sit; 
+				nextItem=sit.current();
+			}
+			if (glv == 0)
+				++it;
+			
+		} 
+		
+		
+		
+			
+			
+		
+	}
+	
+	QTime curTime =QTime::currentTime();
+	qDebug("Time: %d", startTime.secsTo(curTime));
+	
+	//dump hiddenitems...
+	it.toFirst();
+	qDebug("Items in hiddenItems list:");
+	while (it.current()) {
+		qDebug("%s", (const char *) it.currentKey());
+		++it;
+	}
+	
+	
+	
+}
+
+
+
+float NewHeaderList::fuzzyMatch( QString subj, QString cur)
+{
+	QString s1 = makeIndex(subj);
+	if (s1.length() < 10)
+		s1 = sanitize(subj);
+	
+	QString s2 = makeIndex(cur);
+	if (s2.length() < 10)
+		s2 = sanitize(subj);
+	
+	int len = s1.length() < s2.length() ? s1.length() : s2.length();
+	int diff = 0;
+	for (int i = 0 ; i < len; i++) {
+		if (s1.at(i) != s2.at(i))
+			diff++;
+	}
+// 	float temp = (float) (float)diff/(float)len;
+// 	qDebug("Diff: %f", temp);
+	return (float) (1.0 - (float)diff/(float)len);
+	
+}
+
+int NewHeaderList::area( QString s )
+{
+	int area = 0;
+	const char *as = s.latin1();
+	for (uint i = 0; i < s.length(); i++) {
+		if (!s.at(i).isDigit()) {
+			area += as[i];
+		}
+	}
+	return area;
+}
+
+QString NewHeaderList::makeIndex( QString s )
+{
+	int i = 0;
+	int pos;
+	QRegExp rx;
+	rx.setMinimal(false);
+	while (fPatterns[i]) {
+		rx.setPattern(fPatterns[i]);
+		if ( (pos = rx.searchRev(s)) != -1) {
+			//match! cap(1) is the index, cap(2) is the filename
+			return sanitize(rx.cap(1));
+			
+		}
+		i++;
+	}
+	return QString::null;
+	
+}
+
+QString NewHeaderList::sanitize( QString s )
+{
+	QString index;
+	for (uint i = 0; i < s.length(); i++) {
+		if (!s.at(i).isDigit())
+			index+=s.at(i);
+	}
+	return index;
+
+}
+
+void NewHeaderList::slotColSizeChanged( int section, int oldSize, int newSize)
+{
+	kdDebug() << "Section " << section << " Changed its size from " << oldSize << " to " << newSize << endl;
+// 	ng->clearColSize();
+	switch( section ){
+		case 0:
+			ng->setColSize( Subj_Col, newSize);
+			break;
+		case 1:
+			ng->setColSize(Parts_Col, newSize);
+			break;
+		case 2:
+			ng->setColSize( Bytes_Col, newSize);
+			break;
+		case 3:
+			
+			if(showFrom)
+			{
+				ng->setColSize(From_Col, newSize);
+				 
+			} else if (showDate) {
+				ng->setColSize(Date_Col, newSize);
+			}
+			//else it's a server col, won't save the size of this
+			break;
+		case 4:
+			if (showFrom && showDate)
+			{
+				//Date col
+				ng->setColSize( Date_Col, newSize);
+			}
+			break;
+		default:
+			kdDebug() << "Resize of a non-important column\n";
+			break;
+	}
+	
+	
+}
+
+
+
+void NewHeaderList::slotIndexChanged( int section, int fromIndex, int toIndex)
+{
+	kdDebug() << "Section " << section << " Moved from index " << fromIndex << " to index " << toIndex << endl;
+	ng->clearColOrder();
+	ng->setColIndex(Subj_Col, m_headerList->header()->mapToIndex(Subj_Col));
+// 	kdDebug() << "Subj Index:  " << ng->getColIndex( Subj_Col) << endl;
+	ng->setColIndex(Parts_Col, m_headerList->header()->mapToIndex(Parts_Col));
+// 	kdDebug() << "Parts Index:  " << ng->getColIndex( Parts_Col) << endl;
+	ng->setColIndex(Bytes_Col, m_headerList->header()->mapToIndex(Bytes_Col));
+// 	kdDebug() << "Bytes Index:  " << ng->getColIndex( Bytes_Col) << endl;
+	if (showDate) {
+		ng->setColIndex(Date_Col, m_headerList->header()->mapToIndex(Date_Col));
+// 		kdDebug() << "From Index:  " << ng->getColIndex( Date_Col) << endl;
+	}
+	if (showFrom)
+		ng->setColIndex(From_Col, m_headerList->header()->mapToIndex(From_Col));
+	
+		
+	
+// 	ng->setColIndex( section, toIndex);
+	emit sigSaveSettings( ng, showOnlyNew, showOnlyComplete);
+	
+}
+
+void NewHeaderList::slotClearFilter( )
+{
+	m_filterEdit->clear();
+	slotEnterButtonClicked();
+	
+}
+
+void NewHeaderList::slotFocusFilter( )
+{
+	m_filterEdit->setFocus();
+}
+
+void NewHeaderList::saveSettings( )
+{
+	ng->setSortColumn( m_headerList->sortColumn());
+// 	kdDebug() << "Sort column: " << ng->getSortColumn() << endl;
+	SortOrder so = m_headerList->sortOrder();
+	ng->setSortOrder( so == Qt::Ascending ? true : false);
+	emit sigSaveSettings(ng, showOnlyNew, showOnlyComplete);
+}
+
+void NewHeaderList::adjColSize( int col )
+{
+	int w;
+	m_headerList->setColumnWidthMode(col, QListView::Manual);
+	
+	if ((w = ng->getColSize( col )) != -1) {
+		m_headerList->setColumnWidth(col, w);
+	} 
+}
+
+
+
 /*$SPECIALIZATION$*/
 
 
