@@ -38,7 +38,7 @@ class NewHeaderList: public KMdiChildView
 {
 	Q_OBJECT
 	void loadGroup(Db* db);
-	
+	QStringList rxList;
   	NewsGroup *ng;
   	Servers *servers;
 	QToolButton *m_clearButton, *m_enterButton;
@@ -46,6 +46,10 @@ class NewHeaderList: public KMdiChildView
 	KLineEdit *m_filterEdit;
 	KListView *m_headerList;
   	QDict<BHListViewItem> hiddenItems;
+	QDict<BHListViewItem> tempItems;
+	QDict<GListViewItem> itemIndex;
+// 	QDict<GListViewItem> hiddenGItems;
+// 	QMap<QString, BHListViewItem*> matchMap;
 	void markSelectedAs(int);
 	bool showOnlyNew, showOnlyComplete;
 	void filter(const QString &);
@@ -53,6 +57,7 @@ class NewHeaderList: public KMdiChildView
 // 	BHListViewItem *hideItem(BHListViewItem *);
 	void markAllAsRead(Db*);
 	void markGroupAsRead();
+	void saveSettings();
 	
 	//New SmallBinHeader
 	SmallBinHeader *getSmallBinHeader(char *p);
@@ -62,7 +67,11 @@ class NewHeaderList: public KMdiChildView
 	bool showFrom;
 	bool showDetails;
 	bool showDate;
-	
+	inline float fuzzyMatch(QString, QString);
+	inline QString sanitize(QString s);
+	int area(QString s);
+	inline QString makeIndex(QString s);
+	void adjColSize(int col);	
 	
   
 public:
@@ -80,6 +89,7 @@ public:
 	private slots:
 		void slotClearButtonClicked();
 		void slotEnterButtonClicked();
+		
 
 
 
@@ -95,6 +105,14 @@ public slots:
 	void slotShowOnlyComplete();
 	void slotShowOnlyNew();
 	void slotDownloadToFirst(QString, bool);
+	void slotGroupArticles();
+	void slotGroupWithFrom();
+	void slotGroupWithIndex();
+	void slotGroupMatchAdjacent();
+	void slotIndexChanged(int, int, int);
+	void slotClearFilter();
+	void slotFocusFilter();
+	void slotColSizeChanged(int, int, int);
 	
 	
 	
