@@ -20,14 +20,49 @@
 #include "hlistviewitem.h"
 #include "newsgroup.h"
 #include <qpainter.h>
+#include <klocale.h>
+/*
+static const char *patterns[] = { "\\d+\\.(?:avi|mpg|mpeg|wmv)",  //.nn.avi
+	"(?:avi|mpg|mpeg|wmv)\\.\\d+)",  //.avi.nn
+	"(?:\\.r\\d+|\\.rar|\\.part\\d+\\.rar)",    //.rnn, .part01.rar, .rar
+	"(?:\\.PAR|\\.P\\d+)", //PAR, P01, etc
+	"(?:\\.par2|\\vol\\d+\\+\\d+\\.par2)", //.par2, .volnn+nnn-par2
+	"(?:\\.nfo | \\.diz | \\.jpe?g| \\.bmp | \\.txt\\b)", //.nfo, .diz, bmp, etc...
+	"\0"
+};*/
+
+GListViewItem::GListViewItem( KListView* p, BHListViewItem *bhl, bool hf, bool hd) : KListViewItem(p), haveFrom(hf), haveDate(hd)
+{
+	subject = bhl->getSubject();
+	from = bhl->getFrom();
+	size = 0;
+	if (haveDate) {
+		dt = bhl->getDate();
+		//qdt=new QDateTime(QDateTime::fromString(bhl->getDate()));
+	} else dt = 0;
+	setText(Subj_Col, subject);
+	setPixmap(Subj_Col,BarIcon("text_block", KIcon::SizeSmall));
+	setText(Bytes_Col, QString::number(size));
+	parts = 0;
+	setText(Parts_Col, QString::number(parts));
+	prevItems = new KListViewItem(this, i18n("Previews"));
+	postItems = new KListViewItem(this, prevItems, i18n("Data"));
+	parItems = new KListViewItem(this, postItems, i18n("Pars"));
+	setExpandable(true);
+	
+	
+	
+	
+}
 
 BHListViewItem::BHListViewItem( KListView *parent, SmallBinHeader *sbh, Db *_db, bool hf, bool hd, QMap< int, NntpHost * > *_servers )  : KListViewItem(parent), db(_db), servers(_servers), haveFrom(hf), haveDate(hd)
 {
 	subject=sbh->subj;
 	from=sbh->from;
-	if (haveDate)
-		qdt=new QDateTime(QDateTime::fromString(sbh->date));
-	else qdt=0;
+	if (haveDate) {
+		dt = sbh->tDate;
+// 		qdt=new QDateTime(QDateTime::fromString(sbh->date));
+	} else dt=0;
 	status=sbh->status;
 	if (sbh->missingParts == 0) {
 		lineColor=Qt::black;
@@ -49,7 +84,10 @@ BHListViewItem::BHListViewItem( KListView *parent, SmallBinHeader *sbh, Db *_db,
 	if (haveFrom)
 		setText(MAN_COL, from);
 	if (haveDate) {
-		setText(colCount-1, sbh->date);
+		QDateTime qdt;
+		qdt.setTime_t(dt);
+		setText(colCount-1, qdt.toString());
+		//setText(colCount-1, sbh->date);
 // 		kdDebug() << "Have date in col: "<< colCount-1 << " " << sbh->date << endl;
 	}
 	
@@ -67,6 +105,7 @@ BHListViewItem::BHListViewItem( KListView *parent, SmallBinHeader *sbh, Db *_db,
 		}
 	}
 	setExpandable(true);
+	
 }
 
 
@@ -75,9 +114,10 @@ BHListViewItem::BHListViewItem( KListView *parent, BinHeader *bh, Db *_db, bool
 	subject=bh->getSubj();
 	from=bh->getFrom();
 	
-	if (haveDate)
-		qdt=new QDateTime(QDateTime::fromString(bh->getDate()));
-	else qdt=0;
+	if (haveDate) {
+		dt = bh->getDate();
+		//qdt=new QDateTime(QDateTime::fromString(bh->getDate()));
+	}else dt=0;
 	
 	status=bh->getStatus();
 	
@@ -109,8 +149,12 @@ BHListViewItem::BHListViewItem( KListView *parent, BinHeader *bh, Db *_db, bool
 	//From (if exist) is always immediately after the "mandatory" columns
 	if (haveFrom)
 		setText(MAN_COL, from);
-	if (haveDate)
-		setText(colCount-1, bh->getDate());
+	if (haveDate) {
+		QDateTime qdt;
+		qdt.setTime_t(bh->getDate());
+		setText(colCount-1, qdt.toString());
+// 		setText(colCount-1, bh->getDate());
+	}
 	if (servers != NULL) {
 		QMap<int, NntpHost*>::iterator it;
 		int i =0;
@@ -137,7 +181,8 @@ BHListViewItem::BHListViewItem(KListView *parent, BinHeader *bh, Db *_db, QMap<i
 	subject=bh->getSubj();
 	from=bh->getFrom();
 
-	qdt=new QDateTime(QDateTime::fromString(bh->getDate()));
+	dt = bh->getDate();
+	//qdt=new QDateTime(QDateTime::fromString(bh->getDate()));
 	status=bh->getStatus();
 	
 			
@@ -169,7 +214,10 @@ BHListViewItem::BHListViewItem(KListView *parent, BinHeader *bh, Db *_db, QMap<i
 
 // 	setText(Lines_Col, QString::number(bh->getLines()));
 // 	setText(From_Col, bh->getFrom());
-	setText(Date_Col, bh->getDate());
+// 	setText(Date_Col, bh->getDate());
+	QDateTime qdt;
+	qdt.setTime_t(bh->getDate());
+	setText(Date_Col, qdt.toString());
 
 	QMap<int, NntpHost*>::iterator it;
 	int i =0;
@@ -212,7 +260,8 @@ void BHListViewItem::paintCell( QPainter * p, const QColorGroup & cg, int column
 
 BHListViewItem::~ BHListViewItem( )
 {
-	delete qdt;
+// 	if (qdt)
+// 		delete qdt;
 }
 
 void BHListViewItem::setOpen( bool o )
@@ -275,8 +324,12 @@ void BHListViewItem::setOpen( bool o )
 				
 				if (haveFrom)
 					temp->setText(MAN_COL, bh->getFrom());
-				if (haveDate)
-					temp->setText(colCount-1, bh->getDate());
+				if (haveDate) {
+					QDateTime qdt;
+					qdt.setTime_t(bh->getDate());
+					temp->setText(colCount -1, qdt.toString());
+// 					temp->setText(colCount-1, bh->getDate());
+				}
 				temp->setSelectable(false);
 // 				qDebug("Part size: %d", bh->partSize[bh->pnmit.key()]);
 				// Examine per-server parts...
@@ -342,15 +395,11 @@ int BHListViewItem::compare( QListViewItem * i, int col, bool ascending ) const
 	
 // 	if (col == Date_Col) {
 	if (haveDate && col == colCount-1) {
-		
-		
-		
-		if (*qdt < *(((BHListViewItem*)i)->qdt))
-			return -1;
-		else if (*qdt > *(((BHListViewItem*)i)->qdt))
+		if (dt < ((BHListViewItem*)i)->dt)
 			return 1;
+		else if (dt > ((BHListViewItem*)i)->dt)
+			return -1;
 		else return 0;
-// 	} else if ( col == Lines_Col || col == Bytes_Col ) {
 	} else if ( col == Bytes_Col ) {
 		
 		if ( text(col).toInt() < i->text(col).toInt())
@@ -410,4 +459,33 @@ int NGListViewItem::rtti( ) const
 
 
 
+void GListViewItem::addPart( BHListViewItem * bhl )
+{
+	///@todo identify the part type
+	
+	//Add the part - for now just add it to the "data" branch
+	postItems->insertItem(bhl);
+	size+=bhl->getSize();
+	parts+=1;
+	setText(Parts_Col, QString::number(parts));
+	setText(Bytes_Col, QString::number(size));
+	
+	
+}
+
+bool BHListViewItem::operator ==(BHListViewItem *bhl )
+{
+	return (getSubject() == bhl->getSubject());
+}
+
+bool BHListViewItem::operator <( BHListViewItem * bhl )
+{
+	return (getSubject() < bhl->getSubject());
+}
+
+
+
+
+
+
 
