@@ -26,10 +26,12 @@
 // #include "qmgr.h"
 #include <qdatetime.h>
 #include <kiconloader.h>
-
+#include <qdict.h>
 
 #define TITEM 1001
 #define GITEM 1002
+#define GLITEM 1003
+#define BHLITEM 1004
 
 
 //3 mandatory columns
@@ -59,35 +61,66 @@ class BHListViewItem : public KListViewItem {
 		QColor lineColor;
 		bool ok;
 		uint status;
-		QDateTime *qdt;
+		//QDateTime *qdt;
+		uint dt;
 
 		QMap<int, NntpHost*> *servers;
 		
-		char colCount; //Number of FIXED column...
+		char colCount; //Number of FIXED columns...
 		bool haveFrom;
 		bool haveDate;
+		QPixmap *artRead;
+		QPixmap *artUnread;
 		
 	public: 
 	BHListViewItem(KListView*, BinHeader*, Db*, QMap<int, NntpHost*> *_servers);
 	BHListViewItem(KListView*, BinHeader*, Db*, bool, bool, QMap<int, NntpHost*>*);
 	BHListViewItem(KListView*, SmallBinHeader*, Db*, bool, bool, QMap<int, NntpHost*>*);
 	BHListViewItem(KListView*, BinHeader*);
-	QString getDate() {return qdt->toString();};
+	uint getDate() {return dt;}
 	bool isComplete() {return ok;};
 	bool isNew() {return (status == BinHeader::bh_new); };
 	void setStatus(int s) {status=s;};
 	int getStatus() { return status; }
 	QString getSubject() {return subject;};
 	QString getFrom() {return from;};
+	int getSize() {return text(Bytes_Col).toInt();}
 	
-	
+	virtual int rtti() const {return BHLITEM;}
 	virtual void paintCell( QPainter *p, const QColorGroup &cg, int column, int width, int alignment );
 	virtual void setOpen(bool o);
 	virtual int compare(QListViewItem *i, int col, bool ascending) const;
 	Db * getDb() { return db;};
 	~BHListViewItem();
+	bool operator==(BHListViewItem*bhl);
+	bool operator<(BHListViewItem*bhl);
+	
 };
 
+class GListViewItem : public KListViewItem {
+	private:
+		QString subject;
+		QString from;
+		//QDateTime *qdt;
+		uint dt;
+		char colCount;
+		bool haveFrom;
+		bool haveDate;
+		int parts;
+		int size;
+		QMap<QString, BHListViewItem*> posts;
+		KListViewItem *postItems;
+		QMap<QString, BHListViewItem*> pars;
+		KListViewItem *parItems;
+		QMap<QString, BHListViewItem*> previews;
+		KListViewItem *prevItems;
+	public:
+		GListViewItem(KListView *p, BHListViewItem* bhl, bool hf, bool hd);
+		void addPart(BHListViewItem *bhl);
+		QString getSubject() {return subject;}
+		virtual int rtti() const {return GLITEM;}
+		
+};
 	
 
 class NGListViewItem: public KListViewItem {
