@@ -34,7 +34,9 @@
 #include <kkeydialog.h>
 #include <kdeversion.h>
 #include <qfile.h>
-
+#include <kwin.h>
+// // #include <kaction.h>
+#include <kprogress.h>
 #include <kdeversion.h>
 
 #include <kglobal.h>
@@ -49,13 +51,12 @@ klibido::klibido()
 
     // set the shell's ui resource file
     setXMLFile("klibidoui.rc");
-
-	setCaption("KLibido 0.2.4.1");
+// 	createGUI("klibidoui.rc");
+	setCaption("KLibido 0.2.5");
 	dbenv=0;
 	fViewer=0;
 	qMgr=0;
 
-
   if (!Config().configured || !dirCreated()) {
     if(!slotSettingsConfigure()) {
 		KMessageBox::error(this, i18n("Configuration aborted. KLibido will now exit"), i18n("Configuration error")); 	
@@ -78,7 +79,7 @@ klibido::klibido()
   else  migrateDbs();
 	
 	
-	setAutoSaveSettings();
+	
 // 	setupServers();
 	
 	
@@ -106,7 +107,7 @@ klibido::klibido()
 	
 // 	KMdiChildView *QView=new KMdiChildView("Q Manager", this);
 	groupDb=groupList->getGroupDb();
-	qMgr=new QMgr(&servers, groupDb, "Q Manager", this);
+	qMgr=new QMgr(&servers, groupDb, i18n("Q Manager"), this);
 	qMgr->setDbEnv(Config().dbDir, dbenv, groupList);
 
 #if KDE_VERSION >= KDE_MAKE_VERSION(3,3,0)
@@ -166,7 +167,9 @@ klibido::klibido()
 	connect(serversList, SIGNAL(sigPauseThread(int, int )), qMgr, SLOT(slotPauseThread(int, int )));
 	connect(serversList, SIGNAL(sigResumeThread(int, int )), qMgr, SLOT(slotResumeThread(int, int )));
 	
-	statusBar()->show();
+	if(Config().showStatusBar) {
+		statusBar()->show();
+	}
 	statusBar()->message(i18n("Ready"));
 	
 	
@@ -231,13 +234,21 @@ klibido::klibido()
 	/// @todo manage window menu for fViewer
 	connect(wMenu, SIGNAL(activated(int)), this, SLOT(slotWMenuActivated(int)));
 	connect(wMenu, SIGNAL(aboutToShow()), this, SLOT(slotAboutToShow()));
+
+	setAutoSaveSettings("MainWindow", false);
+// 	setAutoSaveSettings();
+// 	setSettingsDirty();
+// 	restoreWindowSize(kapp->config());
+	restoreSize();	
 	qMgr->checkQueue();
 	
+	
+	
 }
 
 klibido::~klibido()
 {
-	qDebug("KLibido::~klibido()");
+	kdDebug() << "KLibido::~klibido()\n";
 	if (qMgr)
 		closeWindow(qMgr);
 // 		
@@ -255,10 +266,6 @@ klibido::~klibido()
 	
 }
 
-void klibido::openNewWindow( )
-{
-	qDebug("Open new Window");
-}
 
 
 
@@ -279,7 +286,11 @@ void klibido::setupDbEnv(QString dir )
 //     if ((ret=dbenv->open((const char *) dir, DB_CREATE | DB_THREAD | DB_INIT_CDB |DB_INIT_MPOOL | DB_PRIVATE, 0644))!= 0)
 	const char *d=dir.latin1();
 	if ((ret=dbenv->open(d, DB_CREATE | DB_THREAD | DB_INIT_CDB |DB_INIT_MPOOL | DB_PRIVATE, 0644))!= 0)
-        qDebug("Error opening non-transactional environment: %s", dbenv->strerror(ret));
+// 	kdDebug() << "Error opening non-transactional environment: " <<  dbenv->strerror(ret) << endl;
+	if ((ret=dbenv->open(d, DB_CREATE | DB_THREAD | DB_INIT_LOCK |  DB_INIT_LOG | DB_INIT_TXN 
+			| DB_RECOVER | DB_INIT_MPOOL | DB_PRIVATE | DB_TXN_WRITE_NOSYNC, 0644))!= 0)
+		kdDebug() << "Error opening transactional environment: " <<  dbenv->strerror(ret) << endl;
+		
 // 	qDebug("error: %s", dbenv->strerror(9));
 	
 	
@@ -289,7 +300,10 @@ void klibido::setupActions( )
 {
 	//Application SLOT
 	KStdAction::quit(this, SLOT(quit()), actionCollection());
-    KStdAction::showStatusbar(this, SLOT(optionsShowStatusbar()), actionCollection());
+	KToggleAction* sbAction=KStdAction::showStatusbar(this, SLOT(optionsShowStatusbar()), actionCollection());
+	if(!Config().showStatusBar) {
+		sbAction->setChecked(false);
+	}
 	KStdAction::preferences(this, SLOT(slotSettingsConfigure()), actionCollection() );
 	KStdAction::keyBindings(this, SLOT(slotShortcutsConfigure()), actionCollection());
 // 	actionToggleQ=new KToggleAction(i18n("Show Queue"), 0, this, SLOT(slotShowQueue()), actionCollection(), "show_queue");
@@ -336,6 +350,11 @@ void klibido::setupActions( )
 	markAsRead=new KAction(i18n("Mark as read"), 0,0,actionCollection(), "mark_as_read");
 	markAsUnread=new KAction(i18n("Mark as unread"), 0, 0, actionCollection(), "mark_as_unread");
 	delHeader = new KAction(i18n("Delete"), 0, 0, actionCollection(), "delete_header");
+#ifndef NDEBUG
+	groupArticles = new KToggleAction(i18n("Group articles"), 0, 0, actionCollection(), "group_articles");
+#endif
+	clearFilter = new KAction(i18n("Clear filter"), CTRL + Key_C, 0, 0, actionCollection(), "clear_filter");
+	focusFilter = new KAction(i18n("Set focus to filter edit"),CTRL + Key_F,  0, 0, actionCollection(), "focus_filter");
 	
 	//Q actions
 	
@@ -346,11 +365,16 @@ void klibido::setupActions( )
 	(void)new KAction(i18n("Resume"), 0, qMgr, SLOT(slotResumeSelected()), actionCollection(), "resume_selected");
 	(void)new KAction(i18n("Cancel"), 0, qMgr, SLOT(slotCancelSelected()), actionCollection(), "cancel_selected");
 	(void)new KAction(i18n("Move to top"), 0, qMgr, SLOT(slotMoveSelectedToTop()), actionCollection(), "move_to_top");
+	(void)new KAction(i18n("Move to bottom"), 0, qMgr, SLOT(slotMoveSelectedToBottom()), actionCollection(), "move_to_bottom");
 // 	(void)new KAction(i18n("Close active view"), CTRL + Key_W, this, SLOT(()), actionCollection(), "close_active_view");
 	
 // 	accel->insert("close_view", i18n("Close Active view"), i18n("Closes the active view"), CTRL + Key_W, this, 
 // 			SLOT(slotCloseActiveView()));
 	closeAction = new KAction(i18n("Close window"), CTRL + Key_W, this, SLOT(slotCloseWindow()), actionCollection(), "close_window");
+// 	kdDebug() << "Actions: " << accel->actions().count() << endl;
+// 	accel->remove("window_close");
+// 	accel->updateConnections();
+// 	kdDebug() << "Actions: " << accel->actions().count() << endl;
 // 	(void)new KAction(i18n("Close and mark as read"), 0, this, SLOT(slotCloseAndMark()), actionCollection(), "close_mark");
 // 	(void)new KAction(i18n("Close and don't mark as read"), 0, this, SLOT(slotCloseAndNoMark()), actionCollection(), "close_nomark");
 	
@@ -385,7 +409,7 @@ void klibido::slotOpenNewsGroup( NewsGroup * ng )
 	
 	NewHeaderList * view=new NewHeaderList(ng, &servers, ng->getName(), this);
 	ng->setView( view );
-	groupList->saveGroup(ng);
+	//groupList->saveGroup(ng);
 	connect(view, SIGNAL(articlePopup(const QPoint &)), this, SLOT(slotPopupArticleMenu(const QPoint& )));
 	
 	connect(view, SIGNAL(activated(KMdiChildView*)), this, SLOT(slotGroupActivated(KMdiChildView* )));
@@ -395,6 +419,7 @@ void klibido::slotOpenNewsGroup( NewsGroup * ng )
 	connect(view, SIGNAL(viewPost(BinHeader*, NewsGroup* )), qMgr, SLOT(slotViewArticle(BinHeader*, NewsGroup* )));
 	connect(view, SIGNAL(updateFinished(NewsGroup* )), groupList, SLOT(slotUpdateFinished(NewsGroup* )));
 	connect(view, SIGNAL(sigSaveSettings(NewsGroup*, bool, bool )), groupList, SLOT(slotSaveSettings(NewsGroup*, bool, bool )));
+	groupList->slotSaveSettings(ng, ng->onlyUnread(), ng->onlyComplete());
 	
 	
 	enable(true);
@@ -511,6 +536,11 @@ void klibido::slotGroupActivated( KMdiChildView * view)
 	disconnect(delHeader, SIGNAL(activated()), 0, 0);
 	disconnect(showOnlyNew, SIGNAL(activated()), 0,0);
 	disconnect(showOnlyComplete, SIGNAL(activated()), 0, 0);
+#ifndef NDEBUG
+	disconnect(groupArticles, SIGNAL(activated()), 0, 0);
+#endif
+	disconnect(focusFilter, SIGNAL(activated()), 0, 0);
+	disconnect(clearFilter, SIGNAL(activated()), 0, 0);
 	
 	
 	
@@ -523,6 +553,11 @@ void klibido::slotGroupActivated( KMdiChildView * view)
 	connect(delHeader, SIGNAL(activated()), view, SLOT(slotDelSelected()));
 	connect(showOnlyNew, SIGNAL(activated()), view, SLOT(slotShowOnlyNew()));
 	connect(showOnlyComplete, SIGNAL(activated()), view, SLOT(slotShowOnlyComplete()));
+#ifndef NDEBUG
+	connect(groupArticles, SIGNAL(activated()), view, SLOT(slotGroupArticles()));
+#endif
+	connect(focusFilter, SIGNAL(activated()), view, SLOT(slotFocusFilter()));
+	connect(clearFilter, SIGNAL(activated()), view, SLOT(slotClearFilter()));
 	
 	
 	
@@ -627,16 +662,16 @@ void klibido::closeWindow( KMdiChildView * pWnd, bool layoutTaskBar  )
 
 void klibido::slotPauseQ( )
 {
-	KToggleAction *actionQ=(KToggleAction*)actionCollection()->action("pause_queue");
+	KToggleAction *actionQ=(KToggleAction*)actionCollection()->action(i18n("pause_queue"));
 	if (actionQ->isChecked()) { //Pause the queue
-		actionQ->setText("Pause Queue");
+		actionQ->setText(("Resume Queue"));
 		actionQ->setIconSet(KGlobal::iconLoader()->loadIcon("connect_no",KIcon::Toolbar, 0, false));
 		//now pause the qcreateIterator
 		qMgr->pauseQ(true);
 		statusBar()->message(i18n("Queue Paused"));
 		
 	} else { //resume the queue
-		actionQ->setText("Resume Queue");
+		actionQ->setText(i18n("Pause Queue"));
 		actionQ->setIconSet(KGlobal::iconLoader()->loadIcon("connect_established",KIcon::Toolbar, 0, false));
 		//now resume the queue
 		qMgr->pauseQ(false);
@@ -650,6 +685,7 @@ void klibido::slotUpdateNewsGroup( NewsGroup * ng, int )
 	
 	NewHeaderList *view;
 	Q_ASSERT(ng);
+	
 	if ((view=ng->getView())) {
 		view->setEnabled(false);
 		
@@ -666,7 +702,7 @@ void klibido::slotUpdateFinished( NewsGroup * ng )
 // 	assert(view);
 	
 	if (view) {
-		qDebug("Re-enabling %s", (const char *) ng->name());
+		kdDebug() << "Re-enabling " <<  ng->name() <<endl;
 		view->reload();
 		view->setEnabled(true);
 	}
@@ -828,7 +864,7 @@ void klibido::migrateDbs( )
 	
 	
 	if (versionDb->open(NULL, "versiondb" , NULL, DB_BTREE, DB_CREATE | DB_THREAD , 0644) != 0)
-		qDebug("Error opening versiondb");
+		kdDebug() << "Error opening versiondb" << endl;
 	//Keys, data have fixed size:
 	//DATA is a uint
 	//KEY is one of GROUPDB, AVAILABLEGROUPSDB, HEADERDB
@@ -853,18 +889,19 @@ void klibido::migrateDbs( )
 		free(data.get_data());
 	} else {
 		//Error!
-		qDebug("Error retrieving version: %d", ret);
+		kdDebug() << "Error retrieving version: %d"<< ret << endl;
 		return;
 	}
 // 	free(data.get_data());
 // 	free(key.get_data());
 // 	qDebug("groupDbVersion: %d", groupDbVersion);
 	
-	if (groupDbVersion != GROUPDB_VERSION) {
+	if (groupDbVersion < GROUPDB_VERSION) {
 		
 		//Migrate the db!
 		
-		qDebug("Need migration %d->%d", groupDbVersion, GROUPDB_VERSION);
+// 		qDebug("Need group db migration %d->%d", groupDbVersion, GROUPDB_VERSION);
+		kdDebug() << "Need group db migration from " << groupDbVersion << " to " << GROUPDB_VERSION << endl;
 // 		free(key.get_data());
 // 		free(data.get_data());
 		Db* groupDb=new Db(dbenv,0);
@@ -875,7 +912,7 @@ void klibido::migrateDbs( )
 // 		qDebug("About to open newsgroup");
 		
 		if (groupDb->open(NULL, "newsgroups", NULL, DB_BTREE, DB_THREAD, 0644!=0)) {
-			qDebug("Error opening groupdb!");
+			kdDebug() << "Error opening groupdb!\n";
 			return;
 		} else qDebug("group db opened");
 		//Now, for all the groups...
@@ -904,7 +941,6 @@ void klibido::migrateDbs( )
 				case 0:
 					tempg->setUnread(0);
 					
-					
 					//now count the unread articles (sic)
 					
 					tempg->getDb()->cursor(0, &dbCursor, 0);
@@ -931,11 +967,15 @@ void klibido::migrateDbs( )
 					tempg->resetSettings();
 					
 				case 3:
-					qDebug("Version 4 of groupDb");
+					kdDebug() << "Version 4 of groupDb\n";
 					tempg->setDeleteOlder(0);
 					break;
+				case 4:
+					tempg->setSortOrder(true);
+					tempg->setSortColumn( -1);
+					break;
 				default:
-					qDebug("Something very very wrong happend with Db versions!");
+					kdDebug() << "Something very very wrong happend with Db versions!\n";
 			 
 			
 			}
@@ -973,7 +1013,12 @@ void klibido::migrateDbs( )
 		
 
 		
-	} 
+	} else if (groupDbVersion > GROUPDB_VERSION) {
+		//Trying to open a newer db...exit NOW
+		KMessageBox::error(this, i18n("Sorry, your Group db is unsupported by this version of KLibido (you probably already migrated the db with a newer version of KLibido)"), i18n("Fatal error"));
+		QApplication::exit(-2);
+		
+	}
 	memset(&key, 0, sizeof(key));
 	memset(&data, 0, sizeof(data));
 	
@@ -994,11 +1039,11 @@ void klibido::migrateDbs( )
 		free(data.get_data());
 	} else {
 		//Error!
-		qDebug("Error retrieving version: %d", ret);
+		kdDebug() << "Error retrieving version: " << ret << endl;
 		return;
 	}
 	
-	if (headerDbVersion != HEADERDB_VERSION) {
+	if (headerDbVersion < HEADERDB_VERSION) {
 		if (KMessageBox::questionYesNo(0, i18n("This version of KLibido uses a different format for the header databases. The operation can be lengthy. Do you want to continue?"), i18n("DB Migration needed")) == KMessageBox::No)
 			exit(-1);
 		
@@ -1015,7 +1060,7 @@ void klibido::migrateDbs( )
 // 		qDebug("About to open newsgroup");
 		
 		if (groupDb->open(NULL, "newsgroups", NULL, DB_BTREE, DB_THREAD, 0644) !=0) {
-			qDebug("Error opening groupdb!");
+			kdDebug() << "Error opening groupdb!\n";
 			return;
 		} else qDebug("group db opened");
 		//Now, for all the groups...
@@ -1026,6 +1071,13 @@ void klibido::migrateDbs( )
 		key.set_flags(DB_DBT_MALLOC);
 		data.set_flags(DB_DBT_MALLOC);
 		NewsGroup *ng;
+		
+		KProgressDialog *kpd = new KProgressDialog(this , NULL, i18n("Migrating dbs"), NULL, true);
+		kpd->showCancelButton(false);
+		kpd->setAllowCancel(false);
+		kpd->setMinimumDuration(1500);
+		QTime previous, current;
+		
 		while ( groupCursor->get(&key, &data, DB_NEXT) == 0 ) {
 			Db* newDb=new Db(dbenv, 0);
 			ng=new NewsGroup(dbenv, (char*)data.get_data());
@@ -1034,7 +1086,7 @@ void klibido::migrateDbs( )
 			Db * oldDb=ng->getDb();
 			QString tempName=ng->getName() + ".new";
 			if (newDb->open(NULL, tempName.latin1(), NULL, DB_BTREE, DB_THREAD | DB_CREATE, 0644) != 0) 
-				qDebug("Error opening temp newsgroup");
+					kdDebug() << "Error opening temp newsgroup\n";
 			else qDebug("Migrating %s in %s", ng->getName().latin1(), tempName.latin1());
 			oldDb->cursor(0, &headerCursor, 0); //No write cursor, read-only
 			BinHeader *bh;
@@ -1043,64 +1095,96 @@ void klibido::migrateDbs( )
 			key.set_flags(DB_DBT_MALLOC);
 			data.set_flags(DB_DBT_MALLOC);
 			int count =0;
+			kpd->setLabel(i18n("Migrating %1").arg(ng->getName()));
+			previous=QTime::currentTime();
 			while (headerCursor->get(&key, &data, DB_NEXT ) == 0) {
 				//Modify the item and put it into the new db...
-				bh=new BinHeader((uchar*)data.get_data(), headerDbVersion);
-				switch (headerDbVersion) {
-					case 0:
-						//Modify the binheader, adding part size
-						for (bh->pnmit = bh->partNum.begin(); bh->pnmit != bh->partNum.end() ; ++(bh->pnmit)) {
-							bh->partSize[bh->pnmit.key()] = 0;
-						}
-					case 1:
-						//Do nothing, just save the articles with empty mid...
-						
-					case 2:
-						//fill lowest for every server...
-						for (bh->pnmit = bh->partNum.begin(); bh->pnmit != bh->partNum.end() ; ++(bh->pnmit)) {
-							//for every part...
-							for (bh->snmit = bh->pnmit.data().begin(); bh->snmit != bh->pnmit.data().end(); 	  ++(bh->snmit)) {
-								//for every server in the part...
-								if (bh->serverLowest.contains(bh->snmit.key()) ) {
-									if ( bh->snmit.data() < bh->serverLowest[bh->snmit.key()] )
-										bh->serverLowest[bh->snmit.key()] = bh->snmit.data();
-								} else bh->serverLowest[bh->snmit.key()] = bh->snmit.data();
-								
-								
+				try {
+					bh=new BinHeader((uchar*)data.get_data(), headerDbVersion, data.get_size());
+					QDateTime qdt;
+					switch (headerDbVersion) {
+						case 0:
+							//Modify the binheader, adding part size
+							for (bh->pnmit = bh->partNum.begin(); bh->pnmit != bh->partNum.end() ; ++(bh->pnmit)) {
+								bh->partSize[bh->pnmit.key()] = 0;
 							}
-						}
-					case 3:
-						//Do nothing, just save the articles with fields rearranged...
-					case 4:
-						//do nothing, save with size
-						break;
-				}
+						case 1:
+							//Do nothing, just save the articles with empty mid...
+							
+						case 2:
+							//fill lowest for every server...
+							for (bh->pnmit = bh->partNum.begin(); bh->pnmit != bh->partNum.end() ; ++(bh->pnmit)) {
+								//for every part...
+								for (bh->snmit = bh->pnmit.data().begin(); bh->snmit != bh->pnmit.data().end(); 	  ++(bh->snmit)) {
+									//for every server in the part...
+									if (bh->serverLowest.contains(bh->snmit.key()) ) {
+										if ( bh->snmit.data() < bh->serverLowest[bh->snmit.key()] )
+											bh->serverLowest[bh->snmit.key()] = bh->snmit.data();
+									} else bh->serverLowest[bh->snmit.key()] = bh->snmit.data();
+									
+									
+								}
+							}
+						case 3:
+							//Do nothing, just save the articles with fields rearranged...
+						case 4:
+							//do nothing, save with size
+							
+						case 5:
+							//Migrate the date
+							qdt = QDateTime::fromString(bh->date);
+							if (!qdt.isValid())
+								qdt = QDateTime::fromString( bh->date, Qt::LocalDate);
+							
+							bh->setDate( qdt.toTime_t());
+						
+						default:
+							break;
+							
+							
+							
+					}
+						
 					
-				
-				
-				//save in the new db
-				free(data.get_data()); //Keep the key, it doesn't change...
-				memset(&data, 0, sizeof(data));
-				uchar *p=bh->data();
-				data.set_data(p);
-				data.set_size(bh->getRecordSize());
-				newDb->put(0, &key, &data, 0);
-				//Free memory and reset the key...
-				delete p;
-				delete bh;
-				
-				//Forgot to free key??
-				free(key.get_data());
-				memset(&key, 0, sizeof(key));
-				key.set_flags(DB_DBT_MALLOC);
-				memset(&data, 0, sizeof(data));
-				data.set_flags(DB_DBT_MALLOC);
-				count ++;
+					
+					//save in the new db
+					free(data.get_data()); //Keep the key, it doesn't change...
+					memset(&data, 0, sizeof(data));
+					uchar *p=bh->data();
+					data.set_data(p);
+					data.set_size(bh->getRecordSize());
+					int ret = newDb->put(0, &key, &data, 0);
+					if(ret != 0)
+						kdDebug() << "Error writing record to new db: " << dbenv->strerror(ret) << endl;
+					//Free memory and reset the key...
+					delete p;
+					delete bh;
+					
+					//Forgot to free key??
+					free(key.get_data());
+					memset(&key, 0, sizeof(key));
+					key.set_flags(DB_DBT_MALLOC);
+					memset(&data, 0, sizeof(data));
+					data.set_flags(DB_DBT_MALLOC);
+					count ++;
+					current=QTime::currentTime();
+					if (previous.msecsTo(current) > 1000)  {
+						kpd->progressBar()->setProgress( uint((float(count)/float(ng->getTotal())) * 100));
+						kapp->processEvents();
+						previous=QTime::currentTime();
+					}
+				} catch (BHException *bhe) {
+					QString r;
+					if (bhe->index() != 0)
+						r = bhe->index() + '\n';
+					else r = "Unknown\n";
+					kdDebug() << "Wrong record: " << r;
+				}
 				//Now rename the new db...
 				
 				
 				
-			}
+			} // While loop
 			headerCursor->close();
 			qDebug("Migrated %d record(s)", count);
 			//DO NOT DELETE newDb
@@ -1127,9 +1211,14 @@ void klibido::migrateDbs( )
 		groupCursor->close();
 		groupDb->close(0);
 		delete groupDb;
+		delete kpd;
 		
+	} else if (HEADERDB_VERSION < headerDbVersion) {
+		KMessageBox::error(this,  i18n("Sorry, your Header db is unsupported by this version of KLibido (you probably already migrated the db with a newer version of KLibido)"), i18n("Fatal error"));
+		QApplication::exit(-2);
 	}
 	
+	
 #if INDEXDB_VERSION != 0	
 	memset(&key, 0, sizeof(key));
 	memset(&data, 0, sizeof(data));
@@ -1262,7 +1351,7 @@ void klibido::migrateDbs( )
 		kdDebug() << "Error retrieving availabegroups version: " << ret << endl;
 		exit(-1);
 	}
-	if (availableGroupsDbVersion != AVAILABLEGROUPSDB_VERSION) {
+	if (availableGroupsDbVersion < AVAILABLEGROUPSDB_VERSION) {
 		//migrate!
 		kdDebug() << "Need grouplist migration from version " << availableGroupsDbVersion << endl;
 		Dbt aGroupsKey, aGroupsData;
@@ -1317,6 +1406,9 @@ void klibido::migrateDbs( )
 		aGroupsDb->close(0);
 		delete aGroupsDb;
 		
+	} else if (AVAILABLEGROUPSDB_VERSION < availableGroupsDbVersion) {
+		KMessageBox::error(this, i18n("Sorry, your Subscribed groups db is unsupported by this version of KLibido (you probably already migrated the db with a newer version of KLibido)"), i18n("Fatal error"));
+		QApplication::exit(-2);
 	}
 
 
@@ -1350,7 +1442,7 @@ void klibido::migrateDbs( )
 	
 	
 	
-	if (serverDbVersion != SERVERDB_VERSION) {
+	if (serverDbVersion < SERVERDB_VERSION) {
 		kdDebug() << "Need serverDb migration: " << serverDbVersion << " -> " << SERVERDB_VERSION << endl;
 		Dbt serverKey, serverData;
 		NntpHost *nh;
@@ -1393,6 +1485,9 @@ void klibido::migrateDbs( )
 		serverCursor->close();
 		serverDb->close(0);
 		delete serverDb;
+	} else if (SERVERDB_VERSION < serverDbVersion) {
+		KMessageBox::error(this, i18n("Sorry, your Server db is unsupported by this version of KLibido (you probably already migrated the db with a newer version of KLibido)"), i18n("Fatal error"));
+		QApplication::exit(-2);
 	}
 	
 	
@@ -1541,12 +1636,15 @@ void klibido::slotShortcutsConfigure( )
 
 void klibido::closeEvent( QCloseEvent * e )
 {
-	if (qMgr->empty())
+	if (qMgr->empty()) {
+		saveSize("MainWindow");
 		e->accept();
-	else {
+
+	} else {
 		int result=KMessageBox::questionYesNo(this, i18n("The download queue is not empty. Are you sure you want to quit?"), i18n("question"));
 		switch (result) {
 			case KMessageBox::Yes:
+				saveSize("MainWindow");
 				e->accept();
 				break;
 			case KMessageBox::No:
@@ -1609,7 +1707,7 @@ void klibido::slotCompactDbs( )
 	enable(false);
 	
 
-emit sigCompact();
+	emit sigCompact();
 	enable(true);
 }
 
@@ -1641,7 +1739,7 @@ bool klibido::dbsExists(QString dbDir)
 void klibido::createDbs()
 {
     qDebug("Create dbs...");
-    //Create the version Db...probably not needed with the new exec path provided by Gonéri, but
+    //Create the version Db...probably not needed with the new exec path provided by GonÃ©ri, but
 	//it shouldn't do any harm :)
 		if (!dbenv)
 			setupDbEnv(Config().dbDir);
@@ -1789,7 +1887,7 @@ WPopupMenu::WPopupMenu( QWidget *p, QString title, KMdiChildView * hl ) :  KPopu
 	NewHeaderList *hList = dynamic_cast<NewHeaderList*>(m_hList);
 	FileViewer *fViewer = dynamic_cast<FileViewer*>(m_hList);
 	if (hList) {
-		insertItem("Close", this, SLOT(slotCloseWindow()));
+		insertItem(i18n("Close"), this, SLOT(slotCloseWindow()));
 		connect(this, SIGNAL(sigCloseWindow(KMdiChildView* )), p, SLOT(slotCloseWindow(KMdiChildView*)));
 		insertItem(i18n("Close and mark as read"), this, SLOT(slotCloseAndMark()));
 		connect(this, SIGNAL(sigCloseAndMark(KMdiChildView*)), p, SLOT(slotCloseAndMark(KMdiChildView*)));
@@ -1798,7 +1896,7 @@ WPopupMenu::WPopupMenu( QWidget *p, QString title, KMdiChildView * hl ) :  KPopu
 		
 	}  else if (fViewer) {
 		if (!Config().singleViewTab) {
-			insertItem("Close", this, SLOT(slotCloseWindow()));
+			insertItem(i18n("Close"), this, SLOT(slotCloseWindow()));
 			connect(this, SIGNAL(sigCloseWindow(KMdiChildView* )), p, SLOT(slotCloseWindow(KMdiChildView*)));
 			insertItem(i18n("Close and delete"), this, SLOT(slotCloseAndMark()));
 			connect(this, SIGNAL(sigCloseAndMark(KMdiChildView*)), p, SLOT(slotCloseAndMark(KMdiChildView*)));
@@ -1835,7 +1933,8 @@ void WPopupMenu::slotCloseAndNoMark( )
 
 void klibido::slotWMenuActivated( int id )
 {
-	qDebug("Activated: %d", id);
+// 	qDebug("Activated: %d", id);
+	kdDebug() << "Activated " << id << endl;
 	
 	if (wMenu->idAt(0) != id) {
 		switch (id) {
@@ -1940,5 +2039,59 @@ void klibido::slotAddServerWidget( NntpHost *nh )
 	
 }
 
+void klibido::restoreSize( )
+{
+	KConfig * conf = kapp->config();
+	conf->setGroup("MainWindow");
+	bool max = conf->readBoolEntry("maximized", false);
+	if (max)
+		setWindowState(WindowMaximized);
+	else restoreWindowSize(conf);
+	
+
+
+// 	showMaximized();
+}
+
+void klibido::saveSize( QString group )
+{
+	KConfig *conf = kapp->config();
+	conf->setGroup(group);
+	int scnum = QApplication::desktop()->screenNumber(parentWidget());
+	QRect desk = QApplication::desktop()->screenGeometry(scnum);
+	QString widthString = QString::fromLatin1("Width %1").arg(desk.width());
+	QString heightString = QString::fromLatin1("Height %1").arg(desk.height());
+	int origWidth = conf->readNumEntry(widthString, 800);
+	int origHeight = conf->readNumEntry(heightString, 600);
+	
+	if (origWidth > desk.width())
+		origWidth = 800;
+	if (origHeight > desk.height())
+		origHeight = 600;
+	
+	int w, h;
+#if defined Q_WS_X11
+	// save maximalization as desktop size + 1 in that direction
+	KWin::WindowInfo info = KWin::windowInfo( winId(), NET::WMState );
+	w = info.state() & NET::MaxHoriz ? origWidth : width();
+	h = info.state() & NET::MaxVert ? origHeight : height();
+#else
+	if (isMaximized()) {
+	w = origWidth;
+	h = origHeight;
+	}
+#endif
+	
+	conf->writeEntry(widthString, w);
+	conf->writeEntry(heightString, h);
+	if (isMaximized()) {
+		conf->writeEntry("maximized", true);
+	}
+	else  {
+		conf->writeEntry("maximized", false);
+		saveWindowSize(conf);
+	}	
+}
+
 
 #include "klibido.moc"
