@@ -152,6 +152,11 @@ private:
 	KAction *serverMenu;
 	KToggleAction *showOnlyComplete;
 	KToggleAction *showOnlyNew;
+	KToggleAction *groupArticles;
+	
+	//New actions for filters...
+	KAction *clearFilter;
+	KAction *focusFilter;
 	
 	
 	NntpHost *libero, *airnews, *astraweb;
@@ -165,7 +170,9 @@ private:
   	bool dbsExists(QString);
   	void createDbs();
 	virtual void closeEvent(QCloseEvent*e);
-
+	void restoreSize();
+	void saveSize(QString group);
+	
 
 
 	
@@ -183,7 +190,7 @@ public:
     virtual ~klibido();
 
 public slots:
-	void openNewWindow();
+	//void openNewWindow();
 	void slotOpenNewsGroup(NewsGroup *ng);
 	void slotActivateNewsGroup(KMdiChildView*pWnd) {activateView(pWnd);};
 	void slotGroupSelection(bool);
