@@ -27,7 +27,7 @@
 static const char description[] =
     I18N_NOOP("KDE Linux Binaries Downloader");
 
-static const char version[] = "0.2.4.1";
+static const char version[] = "0.2.5";
 
 bool g_qResume = 0;
 bool g_qDiscard = 0;
@@ -65,7 +65,9 @@ int main(int argc, char **argv)
 
     if (app.isRestored())
     {
+		kdDebug() << "Apps is restored\n";
         RESTORE(klibido);
+// 		mainWin->restoreSize();
     }
     else
     {
@@ -79,12 +81,9 @@ int main(int argc, char **argv)
 		
         mainWin = new klibido();
         app.setMainWidget( mainWin );
-        mainWin->show();
-		
         args->clear();
     }
-
-    // mainWin has WDestructiveClose flag by default, so it will delete itself.
+	
     return app.exec();
 }
 
