@@ -40,6 +40,8 @@ NewsGroup::NewsGroup( DbEnv * _dbEnv, QString _ngName,  QString _saveDir) {
 	unreadArticles=0;
 	showOnlyComplete=false;
 	showOnlyUnread=false;
+	sortColumn = -1;
+	ascending = true;
 	view =0;
 	deleteOlder=0;
 	listItem = 0;
@@ -169,6 +171,45 @@ char * NewsGroup::data( ) {
 		i+=szInt;
 		
 	}
+	
+	//New in version 5: remember sort column, sort order, column widths, column reordering
+	count = colOrder.count();
+	memcpy(i, &count, szInt);
+	i+=szInt;
+	for (it = colOrder.begin(); it != colOrder.end(); ++it)
+	{
+		id = it.key();
+		w = it.data();
+		memcpy(i, &id, szInt);
+		i+=szInt;
+		memcpy(i, &w, szInt);
+		i+=szInt;
+// 		kdDebug() << "Column: " << id << " index: " << w << endl;
+	}
+	
+	count = colSize.count();
+	memcpy(i, &count, szInt);
+	i+=szInt;
+	
+	for (it = colSize.begin(); it != colSize.end(); ++it)
+	{
+		id = it.key();
+		w = it.data();
+		memcpy(i, &id, szInt);
+		i+=szInt;
+		memcpy(i, &w, szInt);
+		i+=szInt;
+	}
+	
+	memcpy(i, &sortColumn, szInt);
+	i+=szInt;
+	
+	memcpy(i, &ascending, sizeof(bool));
+	
+	
+	
+	
+	
 // 	qDebug("or not?");
 // 	qDebug("data(): i-p: %d", i-p);
 	return p;
@@ -184,7 +225,7 @@ uint NewsGroup::getRecordSize( )
 // 	qDebug("Size of string: %d", ngName.length());
 // 	qDebug("Size of string: %d", dbName.length());
 // 	qDebug("Size of string: %d", saveDir.length());
-	return (10*sizeof(uint) + ngName.length() + alias.length() + category.length()+ dbName.length() + saveDir.length() + 2*high.count()*sizeof(uint) + 2*low.count()*sizeof(uint) + 2*sizeof(bool)  );
+	return (13*sizeof(uint) + ngName.length() + alias.length() + category.length()+ dbName.length() + saveDir.length() + 2*high.count()*sizeof(uint) + 2*low.count()*sizeof(uint) + 2*sizeof(bool) +2*colOrder.count()*sizeof(int) + 2 * colSize.count() * sizeof(int) +sizeof(bool) );
 }
 
 NewsGroup::NewsGroup( DbEnv *_dbEnv, char *data, uint version )
@@ -253,6 +294,38 @@ NewsGroup::NewsGroup( DbEnv *_dbEnv, char *data, uint version )
 		low.insert(id, w);
 		
 	}
+	
+	//new in version 5
+	if (version >= 5) {
+		memcpy(&count, p, szInt);
+		p+=szInt;
+		for (int i = 0; i < count; i++) {
+			memcpy(&id, p, szInt);
+			p+=szInt;
+			memcpy(&w, p, szInt);
+			p+=szInt;
+			colOrder.insert(id, w);
+// 			kdDebug() << "Column order: " << id << " index: " << w << endl;
+			
+		}
+		
+		memcpy(&count, p, szInt);
+		p+=szInt;
+		for (int i = 0; i < count; i++) {
+			memcpy(&id, p, szInt);
+			p+=szInt;
+			memcpy(&w, p, szInt);
+			p+=szInt;
+			colSize.insert(id, w);
+		}
+		memcpy(&sortColumn, p, szInt);
+		p+=szInt;
+		memcpy(&ascending, p, sizeof(bool));
+		
+	
+	}
+	
+	
 // 	qDebug("p-data: %d", p-data);
 	dbEnv=_dbEnv;
 	db=new Db(dbEnv,0);
@@ -314,6 +387,22 @@ void NewsGroup::startUpdating( )
 	ngLock.unlock();
 }
 
+void NewsGroup::stopUpdating()
+{
+	ngLock.lock();
+	updating = false;
+	ngLock.unlock();
+}
+
+bool NewsGroup::isUpdating()
+{
+	bool tmp;
+	ngLock.lock();
+	tmp = updating;
+	ngLock.unlock();
+	return tmp;
+}
+
 void NewsGroup::setAlias( QString  s )
 {
 	alias = s;
@@ -496,3 +585,27 @@ void NewsGroup::decTotal( )
 	else totalArticles = 0;
 }
 
+void NewsGroup::setColIndex( int col, int index )
+{
+	colOrder[col] = index;
+}
+
+int NewsGroup::getColIndex( int col )
+{
+	if (colOrder.contains(col))
+		return colOrder[col];
+	else return -1;
+}
+
+void NewsGroup::setColSize( int col, int size )
+{
+	colSize[col] = size;
+}
+
+int NewsGroup::getColSize( int col )
+{
+	if (colSize.contains(col))
+		return colSize[col];
+	else return -1;
+}
+
