@@ -49,7 +49,7 @@ class NewsGroup{
 	QMap<int, int> low; //holds serverId-HighWatermark
 	QMap<int, int>::iterator it;
 	
-	bool updating;
+	volatile bool updating;
 	NGListViewItem *listItem;
 	uint totalArticles;
 	uint unreadArticles;
@@ -57,6 +57,18 @@ class NewsGroup{
 	bool showOnlyComplete;
 	int deleteOlder;
 	
+	//remember column order
+	QMap<int, int> colOrder;
+	
+	
+	//remember sizes of columns
+	QMap<int, int> colSize;
+	
+	
+	//Remember sort column and sort order
+	int sortColumn;
+	bool ascending;
+	
 	NewHeaderList *view; //tab where this group is displayed, if any
     
 	QString ngName;
@@ -91,8 +103,8 @@ public:
 	void setDb(Db* d) {db=d;}
 	char *data(); //marshal (and close?....hmmm...no)
 	uint getRecordSize();
-	bool isUpdating() {return updating;};
-	void stopUpdating() {updating=false;};
+	bool isUpdating();
+	void stopUpdating();
 	void startUpdating();
 	bool isOpened() {return (view!=0);};
 	QString getName() {return ngName;};
@@ -118,6 +130,24 @@ public:
 	bool onlyUnread() {return showOnlyUnread;}
 	void setDeleteOlder(int i) { deleteOlder = i; }
 	int getDeleteOlder() { return deleteOlder; }
+	
+	void setColIndex(int col, int index);
+	int getColIndex(int col);
+	void clearColOrder() { colOrder.clear();}
+	
+	int getSortColumn() { return sortColumn;}
+	bool getSortOrder() { return ascending;}
+	void setSortColumn(int col) { sortColumn = col;}
+	void setSortOrder(bool a)  { ascending = a;}
+	
+	
+	void setColSize(int col, int size);
+	int getColSize(int col);
+	void clearColSize() { colSize.clear();}
+	void lock() { ngLock.lock(); }
+	void unlock()  {ngLock.unlock();}
+	
+	
 #ifndef NDEBUG
 	void validate();
 #endif
