@@ -40,7 +40,7 @@ char * NntpThreadSocket::m_findEndLine( char * start, char * end )
 }
 
 
-QString NntpThreadSocket::createDateTime( QStringList dateTime) {
+uint NntpThreadSocket::createDateTime( QStringList dateTime) {
 
     int i=(dateTime[0].at(dateTime[0].length()-1) == ',') ? 1:0;
 
@@ -54,7 +54,7 @@ QString NntpThreadSocket::createDateTime( QStringList dateTime) {
 
 
     
-    return dt.toString();
+	return dt.toTime_t();
 
 
 }
@@ -170,7 +170,7 @@ bool NntpThreadSocket::m_sendCmd( QString& cmd, int response )
 	//I know, it's terrible, but its the only way I've found...
 	
 	if (!kes->isValid()) {
-		qDebug("m_sendCmd: Invalid socket");
+		kdDebug() << "m_sendCmd: Invalid socket\n";
 		isLoggedIn=false; 
 		if (!m_connect())
 			return false;
@@ -800,15 +800,17 @@ bool NntpThreadSocket::getXover( QString group)
 #if INDEXDB_VERSION != 0
 	job->ng->oldLow[nHost->id]=job->ng->low[nHost->id];
 #endif
+	int oldHighW = job->ng->high[nHost->id];
 
-            // Now grab the articles from the old hiww to the new highw...
+    // Now grab the articles from the old hiww to the new highw...
 	if (job->artSize == 0) {
-		if ((job->ng->high[nHost->id]) != 0) {
-			articles=highWatermark - job->ng->high[nHost->id]+1;	
+		if (oldHighW != 0) {
+			articles=highWatermark - job->ng->high[nHost->id] + 1;	
 		
 		} else {
 			articles = highWatermark - lowWatermark + 1;
-			job->ng->high[nHost->id]=lowWatermark;
+			//?????
+// 			job->ng->high[nHost->id]=lowWatermark;
 		
 		}
 		job->ng->low[nHost->id]=lowWatermark;
@@ -816,18 +818,18 @@ bool NntpThreadSocket::getXover( QString group)
 		//Grab only last "artSize" articles...
 		
 		
-		if ( (highWatermark - job->artSize)  > job->ng->high[nHost->id] )
-			job->ng->high[nHost->id]= highWatermark - job->artSize;
+		if ( (highWatermark - job->artSize)  > oldHighW )
+			oldHighW = highWatermark - job->artSize;
 		if ( ( highWatermark - job->artSize) > lowWatermark)
 			job->ng->low[nHost->id] = highWatermark - job->artSize;
 		else job->ng->low[nHost->id]=lowWatermark;
 		
-		articles=highWatermark - job->ng->high[nHost->id]+1;
+		articles=highWatermark - oldHighW + 1;
 		
 		
 	}
 	
-	groupArticles=job->ng->totalArticles;
+// 	groupArticles=job->ng->totalArticles;
 	/*
 	//BEGIN DEBUG
 	job->ng->low[nHost->id]=28829971;
@@ -842,16 +844,16 @@ bool NntpThreadSocket::getXover( QString group)
     	step=1;
 	        
 	
-	if (job->ng->high[nHost->id] >=highWatermark) {
-		qDebug("No update necessary");
+	if (oldHighW >=highWatermark) {
+		kdDebug() << "No update necessary\n";
 		return true;
 	}
 	//Check first line
 	
 	
 	
-	cmd="xover " + QString::number(job->ng->high[nHost->id]+1) + "-" + QString::number(highWatermark) + "\r\n";
-	kdDebug() << "Getting articles " << job->ng->high[nHost->id]+1 << '-' << highWatermark << endl;
+	cmd="xover " + QString::number(oldHighW + 1) + "-" + QString::number(highWatermark) + "\r\n";
+	kdDebug() << "Getting articles " << oldHighW + 1 << '-' << highWatermark << endl;
 	
 	if (!m_sendCmd(cmd, NntpThreadSocket::xover))
 		return false;
@@ -875,7 +877,7 @@ bool NntpThreadSocket::getXover( QString group)
 				
 			}
 			else {
-				//This shold be a function....m_parseXoverLine() or something similar...
+				//This should be a function....m_parseXoverLine() or something similar...
 
 // 				s=line;
         		*curbytes += strlen(line);
@@ -1371,13 +1373,13 @@ int NntpThreadSocket::dbBinHeaderPut( Db * db, Header * h, NntpHost * nh ) {
                 // 				qDebug("Header: %s", (const char *) h->m_subj);
                 // 				qDebug("Number: %s", (const char *) h->m_num);
             } else
-                bh->setDate(createDateTime(QStringList::split(" ", h->m_date, true)));
+				bh->setDate(createDateTime(QStringList::split(" ", h->m_date, true)));
 
             // 			qDebug("DateTime is: %s", (const char *) bh->getDate());
             //             				qDebug("Header subj: %s", (const char *) ts);
-            bh->setNumParts(rx.cap(2).toInt());
+         	   bh->setNumParts(rx.cap(2).toInt());
             //             				qDebug("Parts: %d", rx.cap(2).toInt());
-            bh->addPart(rx.cap(1).toInt(), h, nh);
+	            bh->addPart(rx.cap(1).toInt(), h, nh);
 
             //             				qDebug("Part in question: %d", rx.cap(1).toInt());
             uchar *p=bh->data();
@@ -1497,7 +1499,7 @@ void NntpThreadSocket::run( )
 			// Write errors are considered non-fatal for the article...they're mostly out-of space errors.
 			// the queue is paused, and the user's responsibility to restart it, possibly after making 
 			// room on the filesystem :)
-			qDebug("Addjob Failed!");
+			kdDebug() << "Addjob Failed!\n";
 			ce=new NntpThreadEvent(job, Write_Err);
 			
 			queueLock->lock();
@@ -1596,7 +1598,13 @@ void NntpThreadSocket::run( )
 // 					break;
 					
 				} else {
-					
+					/*
+					//BEGIN DEBUG
+					error = NoSuchArticle_Err;
+					errorString = "Sto testando!";
+							
+					//END DEBUG
+					*/
 					if (cancel) {
 						//Job canceled
 // 						*status=NntpThreadSocket::Ready;
@@ -1702,12 +1710,12 @@ void NntpThreadSocket::run( )
 				QApplication::postEvent(parent, ce);
 				break;
 			default:
-				qDebug("NntpThreadSocket::run(): unknown job type!");
+				kdDebug() << "NntpThreadSocket::run(): unknown job type!" << endl;
 		}
 		
 	}
 	//Exited. Why?
-	qDebug("about to exit run() on thread %d,%d", qId, threadId);
+	kdDebug() << "about to exit run() on thread " << qId << ',' << threadId << endl;
 // 	statusLock.lock();
 	//I can finally base this on the status *only* - much cleaner
 	
@@ -1728,7 +1736,7 @@ void NntpThreadSocket::run( )
 			//qDebug("%d, %d: sent ready message", qId, threadId);
 			break;
 		default:
-			qDebug("Error: wrong status %d", status);
+			kdDebug() << "Error: wrong status: " << status << endl;
 			
 		
 	}
@@ -1932,10 +1940,13 @@ bool NntpThreadSocket::m_readLine()
 
 bool NntpThreadSocket::getArticle()
 {
-// 	qDebug("GetArticle!");
-	
+	/*
+	//BEGIN DEBUG 
+	return false;
+	//END DEBUG
+	*/
 	if (!m_connect()) {
-		qDebug("getArticle(): can't connect");
+		kdDebug() << "getArticle(): can't connect\n";
         return false;
 	}
 	error=NntpThreadSocket::No_Err;
