@@ -89,6 +89,7 @@ void PrefDialog::accept( )
 		//View
 		Config().activateTab=prefView->activateBtn->isChecked();
 		Config().singleViewTab=prefView->oneTabBtn->isChecked();
+		Config().showStatusBar=prefView->statusBtn->isChecked();
 		
 		if ( prefView->deleteBtn->isChecked()) {
 			Config().dViewed=Configuration::Yes;
@@ -108,8 +109,13 @@ void PrefDialog::accept( )
 		Config().showDetails=prefHeader->detailsCheck->isChecked();
 		Config().allowExpansion=prefHeader->expandCheck->isChecked();
 		Config().showDate = prefHeader->dateCheck->isChecked();
+		
 		Config().alwaysDoubleClick=prefHeader->viewCheck->isChecked();
 		Config().keepListSettings=prefHeader->memCheck->isChecked();
+		Config().rememberSort = prefHeader->sortCheck->isChecked();
+		Config().rememberOrder = prefHeader->orderCheck->isChecked();
+		Config().rememberWidth = prefHeader->sizeCheck->isChecked();
+		
 		
 		if (prefHeader->markBtn->isChecked())
 			Config().markOpt=Configuration::Yes;
