@@ -52,11 +52,11 @@ QMgr::QMgr(Servers *_servers, Db *_gdb, QString caption, QWidget* parent) : KMdi
 	
 // 	queueList=new KListView();
 	queueList=new MyListView();
-	queueList->addColumn("Id");
-	queueList->addColumn("Item");
-	queueList->addColumn("Status");
-	queueList->addColumn("Info");
-	queueList->addColumn("ETA (HH:MM:SS)");
+	queueList->addColumn(i18n("Id"));
+	queueList->addColumn(i18n("Item"));
+	queueList->addColumn(i18n("Status"));
+	queueList->addColumn(i18n("Info"));
+	queueList->addColumn(i18n("ETA (HH:MM:SS)"));
 	queueList->setColumnAlignment(4, Qt::AlignRight);
 // 	queueList->setIcon(KGlobal::iconLoader()->loadIcon("queue", KIcon::Small, 0, false));
 	//Initialize the KListView
@@ -68,12 +68,12 @@ QMgr::QMgr(Servers *_servers, Db *_gdb, QString caption, QWidget* parent) : KMdi
 	queueList->setAllColumnsShowFocus(true);
 	queueList->setSelectionMode(QListView::Extended);
 	
-	tabWidget->addTab(queueList, KGlobal::iconLoader()->loadIcon("queue", KIcon::Small, 0, false), "Queued Items");
+	tabWidget->addTab(queueList, KGlobal::iconLoader()->loadIcon("queue", KIcon::Small, 0, false), i18n("Queued Items"));
 	
 	doneList=new KListView();
-	doneList->addColumn("Id");
-	doneList->addColumn("Item");
-	doneList->addColumn("Info");
+	doneList->addColumn(i18n("Id"));
+	doneList->addColumn(i18n("Item"));
+	doneList->addColumn(i18n("Info"));
 	doneList->setRootIsDecorated(true);
 	doneList->setSorting(-1);
 	doneList->setAcceptDrops(false);
@@ -82,12 +82,12 @@ QMgr::QMgr(Servers *_servers, Db *_gdb, QString caption, QWidget* parent) : KMdi
 	doneList->setAllColumnsShowFocus(true);
 	doneList->setSelectionMode(QListView::Extended);
 // 	doneList->setIcon(KGlobal::iconLoader()->loadIcon("finish", KIcon::Small, 0, false));
-	tabWidget->addTab(doneList,KGlobal::iconLoader()->loadIcon("finish", KIcon::Small, 0, false), "Finished Items");
+	tabWidget->addTab(doneList,KGlobal::iconLoader()->loadIcon("finish", KIcon::Small, 0, false), i18n("Finished Items"));
 	
 	failedList=new KListView();
-	failedList->addColumn("Id");
-	failedList->addColumn("Item");
-	failedList->addColumn("Info");
+	failedList->addColumn(i18n("Id"));
+	failedList->addColumn(i18n("Item"));
+	failedList->addColumn(i18n("Info"));
 	failedList->setRootIsDecorated(true);
 	failedList->setSorting(-1);
 	failedList->setAcceptDrops(false);
@@ -95,7 +95,7 @@ QMgr::QMgr(Servers *_servers, Db *_gdb, QString caption, QWidget* parent) : KMdi
 	failedList->setItemMargin(3);
 	failedList->setAllColumnsShowFocus(true);
 	failedList->setSelectionMode(QListView::Extended);
-	tabWidget->addTab(failedList,KGlobal::iconLoader()->loadIcon("stop", KIcon::Small, 0, false), "Failed Items");
+	tabWidget->addTab(failedList,KGlobal::iconLoader()->loadIcon("stop", KIcon::Small, 0, false), i18n("Failed Items"));
 	
 	//for every server, create the q, the qinfo and the qthreads...
 	QMap<int, NntpHost*>::iterator sit;
@@ -546,6 +546,7 @@ void QMgr::start( Job * j )
 	queue[j->qItemId]->start(j->partId);
 	queueLock.unlock();
 	threads[j->qId][j->threadId]->started();
+	emit sigThreadStart(j->qId, j->threadId);
 	
 	
 	
@@ -585,7 +586,7 @@ void QMgr::finished( Job * j )
 		} else if (j->jobType == Job::UpdHead) {
 			if (queue[j->qItemId]->parts[j->partId]->status == QItem::Requeue_Part) {
 				j->status = Job::Queued_Job;
-				kdDebug() << "Requeing!\n";
+				kdDebug() << "Requeing update job\n";
 				queue[j->qItemId]->requeue(j->partId);
 			} else if ( queue[j->qItemId]->finished(j->partId) ) {
 				queueLock.unlock();
@@ -749,7 +750,7 @@ void QMgr::error( Job * j )
 			requeue(j);
 			break;
 		default:
-			qDebug("Error: should not be here");
+			kdDebug() << "Error: should not be here\n";
 	}
 	queueLock.unlock();
 	
@@ -1043,22 +1044,43 @@ void QMgr::customEvent( QCustomEvent * e)
 			sqe = (SaveQThreadEvent*) e;
 			switch (sqe->event) {
 				case SaveQThreadEvent::SQT_DelNZB:
-					qDebug("Delete nzb");
+					kdDebug() << "Delete nzb\n";
 					delNzbItem(sqe->nzbIndex);
 					break;
 				case SaveQThreadEvent::SQT_Error:
 					kdDebug() << "Error saving queue!\n";
-					qDebug("Error saving queue!");
+					
 					writeError(0);
 					break;
 			}
 			break;
 		case DECODETHREADEVENT:
 			dte=(DecodeThreadEvent*) e;
-			if (dte->diskErr)
-				writeError();
-			else decodeFinished(dte->item, dte->ok, dte->fileName,  dte->error);
-			break;
+			switch (dte->event) {
+				case DecodeThreadEvent::Dte_End:
+				if (dte->diskErr)
+					writeError();
+				else decodeFinished(dte->item, dte->ok, dte->fileName,  dte->error);
+				break;
+				case DecodeThreadEvent::Dte_Progress:
+					//TODO: Show progress
+					dte->item->updateDecodingProgress( dte->progress);
+					break;
+				case DecodeThreadEvent::Dte_Canceled:
+					//TODO: I canceled the item!
+					kdDebug() << "Item id in customEvent: " << dte->item->qItemId << endl;
+					decodeItemCanceled(dte->item);
+					break;
+				case DecodeThreadEvent::Dte_Canceling:
+					//TODO: I'm about to cancel the item
+					break;
+				case DecodeThreadEvent::Dte_Start:
+					//TODO: start decoding
+					dte->item->startDecoding();
+					break;
+			}
+			break; 
+				
 		case UPDATEDBTHREADEVENT:
 			ude=(UpdateDbThreadEvent*) e;
 			switch(ude->type) {
@@ -1091,6 +1113,15 @@ void QMgr::customEvent( QCustomEvent * e)
 					qDebug("Error updating Db");
 					upDbErr(ude->j);
 					break;
+				case UpdateDbThreadEvent::UpDb_Canceling:
+					//TODO: I'm about to cancel the item
+					
+					break;
+				case UpdateDbThreadEvent::UpDb_Canceled:
+// 					queue[ude->j->qItemId]->canceled(ude->j->partId);
+					kdDebug() << "UpdItem canceled\n";
+					cancel(ude->j);
+					break;
 					
 			}
 			
@@ -1165,7 +1196,7 @@ void QMgr::customEvent( QCustomEvent * e)
 					downloadCanceled(nte->job);
 					break;
 				case NntpThreadSocket::DownloadError:
-					qDebug("download error");
+					kdDebug() << "download error\n";
 // 					downloadError(nte->job);
 					switch (nte->err) {
 						case NntpThreadSocket::NoSuchGroup_Err:
@@ -1174,7 +1205,7 @@ void QMgr::customEvent( QCustomEvent * e)
 							break;
 						case NntpThreadSocket::Write_Err:
 							//Argh...
-							qDebug("Write error during header update");
+							kdDebug() << "Write error during header update\n";
 							downloadError(nte->job);
 							//Pause the queue...
 							writeError();
@@ -1266,51 +1297,85 @@ void QMgr::slotCancelSelected( )
 	queueLock.lock();
 	while(it.current()) {
 		
+		
 		QItem *item=queue[it.current()->text(0).toInt()];
 		QMap<int, Part*>::iterator pit;
 		NewsGroup *ng=0;
 		Part *part;
+		if (item->type == Job::GetPost && item->processing) {
+			//Item is in the decoding queue...
+			decodeThread->cancel(item->qItemId);
+			
+			
+		} else {
 		
-		for (pit=item->parts.begin(); pit != item->parts.end(); ++pit) {
-// 			queueLock.lock();
-			
-			part=pit.data();
-			
-			if (part->job->status==Job::Queued_Job || part->job->status == Job::Paused_Job) {
-				part->job->status=Job::Canceled_Job;
-				if (part->job->jobType == Job::GetPost)
-					(*servers)[part->job->qId]->size-=part->job->artSize;
-				item->canceled(part->job->partId); //ugly
-				ng=part->job->ng;
-// 				part->job->status=Job::Canceled_Job;
-// 				part->listItem->setText(2, "Canceled job");
-			}
-			else if (part->job->status==Job::Processing_Job) {
-// 				qDebug("Job is running: %d", part->job->id);
-// 				qDebug("cancelling thread...");
-				part->listItem->setText(2, "Canceling job...");
-				threads[part->job->qId][part->job->threadId]->threadCancel();
-				emit sigThreadCanceling(part->job->qId, part->job->threadId);
+			for (pit=item->parts.begin(); pit != item->parts.end(); ++pit) {
+	// 			queueLock.lock();
+				
+				part=pit.data();
+				
+				if (part->job->status==Job::Queued_Job || part->job->status == Job::Paused_Job) {
+					part->job->status=Job::Canceled_Job;
+					if (part->job->jobType == Job::GetPost)
+						(*servers)[part->job->qId]->size-=part->job->artSize;
+					item->canceled(part->job->partId); //ugly
+					ng=part->job->ng;
+	// 				part->job->status=Job::Canceled_Job;
+	// 				part->listItem->setText(2, "Canceled job");
+				}
+				else if (part->job->status==Job::Processing_Job) {
+	// 				qDebug("Job is running: %d", part->job->id);
+	// 				qDebug("cancelling thread...");
+					part->listItem->setText(2, i18n("Canceling job..."));
+					threads[part->job->qId][part->job->threadId]->threadCancel();
+					emit sigThreadCanceling(part->job->qId, part->job->threadId);
+					
+				} else if (part->job->status == Job::Updating_Job) {
+					kdDebug() << "Canceling item in update db status\n";
+					updateDbThread->cancel( part->jobId);
+				}
 				
 			}
+			if (item->partsToDo == 0) {
+				if (item->type == Job::UpdHead) {
+					queueLock.unlock();
+					emit sigUpdateFinished(ng);
+					queueLock.lock();
+				}
+				moveCanceledItem(item);
+			}
+			
+			
 			
 		}
-		if (item->partsToDo == 0) {
-			if (item->type == Job::UpdHead) {
-				queueLock.unlock();
-				emit sigUpdateFinished(ng);
-				queueLock.lock();
-			}
-			moveCanceledItem(item);
-		}
-		
 		++it;
-		
 	}
 	queueLock.unlock();
 	
 }
 
+void QMgr::itemCanceling(QItem *item)
+{
+	item->listItem->setText(2, i18n("Canceling..."));
+}
+
+void QMgr::decodeItemCanceled( QPostItem * item )
+{
+	/*
+	QMap<int, Part*>::iterator pit;
+	for (pit=item->parts.begin(); pit != item->parts.end(); ++pit) {
+	// 			queueLock.lock();
+				
+		part=pit.data();
+		part->job->status = Job::Canceled_Job;
+// 		(*servers)[part->job->qId]->size-=part->job->artSize;
+		item->canceled( part->job->partID);
+	}*/
+	moveCanceledItem(item);
+	
+}
+
+
 
 
 void QMgr::decodeFinished( QPostItem *item, bool ok, QString fileName, QString err )
@@ -1328,7 +1393,7 @@ void QMgr::decodeFinished( QPostItem *item, bool ok, QString fileName, QString e
 		fileWithPath=item->getSavePath();
 		fileWithPath += fileName;
 	} else {
-		fileWithPath="No file decoded";
+		fileWithPath=i18n("No file decoded");
 	}
 	//so I can unlock the queue before viewing the file...
 	bool view = item->view;
@@ -1347,10 +1412,10 @@ void QMgr::decodeFinished( QPostItem *item, bool ok, QString fileName, QString e
 	temp->setText(0, QString::number(item->qItemId));
 	temp->setText(1, item->listItem->text(1));
 	if (ok)
-		temp->setText(2, "Decoded to " + fileWithPath);
+		temp->setText(2, i18n("Decoded to ") + fileWithPath);
 	else {
 		if (!fileName.isEmpty())
-			temp->setText(2, "Error decoding " + fileWithPath + ": " + err);
+			temp->setText(2, i18n("Error decoding ") + fileWithPath + ": " + err);
 		else temp->setText(2, err);
 	}
 	QFile::remove(item->getFName());
@@ -1655,7 +1720,7 @@ void QMgr::moveCanceledItem( QItem *item )
 	temp=new KListViewItem(failedList, failedList->lastChild());
 	temp->setText(0, QString::number(item->qItemId));
 	temp->setText(1, item->listItem->text(1));
-	temp->setText(2, "User Cancel");
+	temp->setText(2, i18n("User Cancel"));
 	
 	QMap<int, Part*>::iterator pit;
 	for (pit=item->parts.begin(); pit != item->parts.end(); ++pit) {
@@ -1673,7 +1738,7 @@ void QMgr::moveCanceledItem( QItem *item )
 		
 		child->setText(0, QString::number(pit.data()->jobId));
 		child->setText(1, pit.data()->desc);
-		child->setText(2, "Canceled");
+		child->setText(2, i18n("Canceled"));
 		after=child;
 				
 		
@@ -1735,6 +1800,29 @@ void QMgr::slotFailedContextMenu( QListViewItem *, const QPoint &p )
 	emit sigShowFailedMenu(p);
 }
 
+void QMgr::slotMoveSelectedToBottom( )
+{
+	QPtrList<QListViewItem> selection = queueList->selectedItems();
+	QPtrListIterator<QListViewItem> it(selection);
+	QListViewItem *lastItem = queueList->lastItem();
+	kdDebug() << "Last item: " << lastItem->text(0) << endl;	
+	if (lastItem->depth() != 0)
+		lastItem = lastItem->parent();
+	while (it.current()) {
+		QListViewItem *prevItem = (*it)->itemAbove();
+		if (prevItem->depth() != 0) {
+			prevItem=prevItem->parent();
+			
+		}
+// 		queueList->takeItem(*it);
+// 		queueList->insertItem(it);
+		(*it)->moveItem(lastItem);
+// 		slotItemMoved(*it, prevItem, lastItem);
+		lastItem = *it;
+		++it;
+	}
+}
+
 void QMgr::slotMoveSelectedToTop( )
 {
 	QPtrList<QListViewItem> selection=queueList->selectedItems();
@@ -1755,9 +1843,6 @@ void QMgr::slotMoveSelectedToTop( )
 	
 }
 
-void QMgr::slotMoveSelectedToBottom( )
-{
-}
 
 /*
 void QMgr::slotThreadDisconnected( int serverId, int threadId)
@@ -1898,10 +1983,11 @@ bool QMgr::empty( )
 
 void QMgr::downloadFinished( Job *j )
 {
-	kdDebug() << "DownloadFinished\n";
+	kdDebug() << "Download of headers finished\n";
 	//Adds the job to the updatedb queue
 	queueLock.lock();
 	j->status=Job::Updating_Job;
+	((QUpdItem*)queue[j->qItemId])->downloadFinished(j->partId);
 	queueLock.unlock();
 	updateListLock.lock();
 	updateJobList.append(j);
@@ -1909,7 +1995,7 @@ void QMgr::downloadFinished( Job *j )
 	
 	if (!updateDbThread->running())
 		updateDbThread->start();
-	((QUpdItem*)queue[j->qItemId])->downloadFinished(j->partId);
+	
 	
 // 	emit sigThreadFinished(j->qId, j->threadId);
 	
@@ -1992,12 +2078,12 @@ void QMgr::startAllThreads( int qId )
 
 void QMgr::stopped( int qId, int threadId )
 {
-	qDebug("%d,%d: QMgr::stopped()", qId, threadId);
+// 	qDebug("%d,%d: QMgr::stopped()", qId, threadId);
 	if (threads[qId][threadId]->stop())
 		emit sigThreadFinished(qId, threadId);
 	else {
 		emit sigThreadDisconnected(qId, threadId);
-		qDebug("%d,%d disconnected", qId, threadId);
+// 		qDebug("%d,%d disconnected", qId, threadId);
 	}
 	
 
@@ -2536,7 +2622,7 @@ void QMgr::slotOpenNzb( )
 				bh->setFrom(e.attribute("poster"));
 				QDateTime qdt;
 				qdt.setTime_t(e.attribute("date").toUInt());
-				bh->setDate(qdt.toString());
+				bh->setDate(qdt.toTime_t());
 				bh->setStatus(BinHeader::bh_new);
 				bh->setNumParts(capTotal);
 				QDomNode fileSubNode = e.firstChild();
@@ -2662,6 +2748,7 @@ void QMgr::started( int serverID, int threadID )
 
 
 
+
 /*$SPECIALIZATION$*/
 
 
