@@ -129,6 +129,8 @@ class QMgr : public KMdiChildView
 	void delayedDelete(int qId, int threadId);
 	void writeError(Job *j=0);
 	void started(int serverID, int threadID);
+	void decodeItemCanceled(QPostItem* item);
+	void itemCanceling(QItem *item);
 	
 // 	void updateSaveQueueError();
 	
