@@ -21,6 +21,9 @@
 #include "queueparts.h"
 #include <qfileinfo.h>
 
+
+
+
  
  void QUpdItem::update( int partId,  int partial, int total, int  )
 {
@@ -39,6 +42,7 @@ QItem::QItem( KListView * parent, int id, int _type, NewsGroup *_ng)
 	failedParts=0;
 	totalParts=0;
 	workingThreads=0;
+	processing = false;
 	
 // 	listItem=new KListViewItem(parent, QString::number(id), "Update " + _ng->dbName);
 	listItem=new KListViewItem(parent, parent->lastChild());
@@ -83,6 +87,7 @@ QItem::QItem( KListView * parent, int id, int _type, BinHeader *bh, bool first)
 	totalParts=0;
 	failedParts=0;
 	workingThreads=0;
+	processing=false;
 // 	if (!parent->childCount()) {
 // 		listItem=new KListViewItem(parent, QString::number(id), bh->getSubj());
 // 		
@@ -113,6 +118,7 @@ QItem::QItem( KListView * parent, int id, int _type )
 	listItem=new KListViewItem(parent, parent->lastChild());
 	listItem->setText(0, QString::number(id));
 	listItem->setText(1, "Get list of all groups");
+	processing = false;
 }
 
 
@@ -379,6 +385,18 @@ void QPostItem::update( int partId, int partial, int total, int lastIntervalLine
 }
 
 
+void QPostItem::updateDecodingProgress(int prog)
+{
+	listItem->setText(2, i18n("Decoding (") + QString::number(prog) + "%)");
+}
+
+void QPostItem::startDecoding()
+{
+	listItem->setText(2, i18n("Decoding..."));
+}
+
+
+
 bool QPostItem::finished( int partId )
 {
 	QItem::finished(partId);
@@ -394,12 +412,12 @@ bool QPostItem::finished( int partId )
 			delete etaTimer;
 			etaTimer=0;
 		}
-		listItem->setText(2, "Decoding");
+		listItem->setText(2, i18n("Waiting for decoding..."));
 		listItem->setText(3, "");
 		listItem->setText(4, "");
 		
 		
-		
+		processing = true;
 		emit decodeMe(this);
 		return true;
 	}else  {
@@ -429,7 +447,7 @@ Thread::Thread(uint _serverId, uint _threadId, uint to, uint rc, QWidget * p ) :
 	timeout=to*1000;
 	threadBytes=new uint;
 	*threadBytes=0;
-// 	prevBytes=0;
+	prevBytes=0;
 	resetSpeed();
 // 	status=NntpThreadSocket::Ready;
 	nt=new NntpThreadSocket(p, threadBytes);
@@ -495,13 +513,6 @@ bool Thread::stop( )
 		return false;
 	}
 
-
-	
-	
-	return false;
-	
-	
-
 }
 
 void Thread::slotSpeedTimeout( )
@@ -606,7 +617,43 @@ DecodeThread::DecodeThread(QWidget *p, QMutex *mutex, QValueList< QPostItem * >
 	
 }*/
 
-DecodeThread::DecodeThread(QWidget *p, QMutex *mutex, QValueList< QPostItem * > *decodeList) : DecoderThread(p, mutex, decodeList) {}
+DecodeThread::DecodeThread(QWidget *p, QMutex *mutex, QValueList< QPostItem * > *decodeList) : DecoderThread(p, mutex, decodeList)
+{
+	uu = new UUCallBack();
+	uu->parent = p;
+	uu->cancel = &m_cancel;
+	uu->item = 0;
+}
+
+void SelfDecodeThread::run( )
+{
+// 	kdDebug() << "Starting decode thread...\n";
+	while(!items->isEmpty()) {
+		listLock->lock();
+		item=items->first();
+		listLock->unlock();
+		if ( decode(item )) {
+			listLock->lock();
+			items->remove(items->first());
+			item=0;
+			listLock->unlock();
+			
+		} else if (m_cancel) {
+			kdDebug() << "Canceled item id: " << item->qItemId << endl;
+			DecodeThreadEvent *dte = new DecodeThreadEvent(item, DecodeThreadEvent::Dte_Canceled);
+			listLock->lock();
+			items->remove(items->first());
+			item = 0;
+			m_cancel = false;
+			listLock->unlock();
+			QApplication::postEvent(parent, dte);
+		} else break;
+
+	}
+// 	kdDebug() << "Exiting decode thread...\n";
+	
+}
+
 
 void DecodeThread::run( )
 {
@@ -615,11 +662,25 @@ void DecodeThread::run( )
 // 	qDebug("DecodeThread::run(): Items in queue: %d", items->count());
 	
 	while(!items->isEmpty()) {
-		
-		if (decode(items->first())) {
+		listLock->lock();
+		item = items->first();
+		listLock->unlock();
+		if (decode(item)) {
 			listLock->lock();
 			items->remove(items->first());
+			item = 0;
 			listLock->unlock();
+		} else  if (m_cancel) {
+			//Canceled the item...
+			DecodeThreadEvent *dte = new DecodeThreadEvent(item, DecodeThreadEvent::Dte_Canceled);
+			listLock->lock();
+			items->remove(items->first());
+			item = 0;
+			m_cancel = false;
+			listLock->unlock();
+			QApplication::postEvent(parent, dte);
+			
+					
 		} else break;
 
 	}
@@ -629,87 +690,143 @@ void DecodeThread::run( )
 }
 
 
+//Static function to get the progress of the decoding...
+
+static int busyCallback( void *opaque, uuprogress * uuprog )
+{
+// 	bool *canc = (bool*) opaque;
+// 	DecoderThread *dt = (DecoderThread*) opaque;
+	UUCallBack *uu = (UUCallBack*) opaque;
+	DecodeThreadEvent *dte;
+	kdDebug() << "Cancel: " << *(uu->cancel) << endl;
+// 	kdDebug() << "Parent: " << uu->parent << endl;
+	if (*(uu->cancel)) {
+		//Cancel loading/decoding
+		dte = new DecodeThreadEvent(uu->item, DecodeThreadEvent::Dte_Canceling);
+		QApplication::postEvent(uu->parent, dte);
+		return -1;
+	} else if (uuprog->action  == UUACT_DECODING) {
+		//float progress = ((float)100*((float)uuprog->partno) + ((float)uuprog->percent))/(float)(uuprog->numparts);
+		int progress = (100 * uuprog->partno - uuprog->percent) / uuprog->numparts;
+		kdDebug() << "Part " << uuprog->partno << " progress: " << uuprog->percent << endl;
+		kdDebug( ) << "Total progress: " << progress << endl;
+		dte = new DecodeThreadEvent(uu->item, DecodeThreadEvent::Dte_Progress);
+		dte->setProgress(progress);
+		QApplication::postEvent(uu->parent, dte);		
+	}
+	return 0;
+	
+}
+
+
+
 bool DecodeThread::decode(QPostItem *postItem )
 {
 // 	qDebug("DecodeThread::decode()");
-	uulist *item;
+	DecodeThreadEvent *dte = new DecodeThreadEvent(postItem, DecodeThreadEvent::Dte_Start);
+	QApplication::postEvent(parent, dte);
+	dte = NULL;
+	uulist *UUItem;
 	int res;
 	
 	QTime start, end;
 	start = QTime::currentTime();
+	uu->item = postItem;
 	
-	DecodeThreadEvent *dte = NULL;
 	UUInitialize();
-	UUSetOption(UUOPT_FAST, 1, NULL);
+	UUSetOption(UUOPT_FAST, 0, NULL);
 	//BEGIN modified for debug
-	UUSetOption(UUOPT_OVERWRITE, overWrite , NULL);
+	UUSetOption(UUOPT_OVERWRITE, m_overWrite , NULL);
 	//END modified for debug
 	UUSetOption(UUOPT_DESPERATE, 1, NULL);
 	UUSetOption(UUOPT_SAVEPATH, 0, postItem->getSavePath());
 	UUSetOption(UUOPT_REMOVE, 0, NULL);
+// 	int (*cb)(void*, uuprogress*);
+// 	cb = (int (*) ( void*, uuprogress*)) busyCallback(void*, uuprogress* );
+	UUSetBusyCallback(uu, busyCallback, 500);
 	QMap<int, Part *>::iterator pit;
 	bool errorFlag=false;
 	
-	
+	kdDebug() << "Cancel: " << m_cancel << endl;
 	for (pit=postItem->parts.begin(); pit != postItem->parts.end() ; ++pit) {
 		QString file=postItem->getFName() + '.' + QString::number(pit.key());
-// 		kdDebug() << "Loaded " << postItem->getFName() << '.' << pit.key() << endl;
+		kdDebug() << "Loaded " << postItem->getFName() << '.' << pit.key() << endl;
 // 		if ((res=UULoadFileWithPartNo( (char*)((const char *) file) , NULL, 0, pit.key())) != UURET_OK)
 		if ((res=UULoadFile( (char*)((const char *) file) , NULL, 0)) != UURET_OK)
 		{
-			qDebug("Error loading part %d", pit.key());
+			kdDebug() << "Error loading part " << pit.key() << ": " << res << endl;
 		}
+		if (m_cancel) {
+			UUCleanUp();
+			if (dte)
+				delete dte;
+			return false;
+		}
+		
 	}
 	int i;
-	for (i = 0; (item=UUGetFileListItem(i)) != NULL; i++) {
+	for (i = 0; (UUItem=UUGetFileListItem(i)) != NULL; i++) {
 		
-		if ((item->state & UUFILE_OK) == 0) {
-			qDebug("Error decoding post");
+		if ((UUItem->state & UUFILE_OK) == 0) {
+			kdDebug() << "Error decoding post\n";
 			dte=new DecodeThreadEvent(false, postItem);
-			QString error="Error(s): ";
-			if ((item->state & UUFILE_MISPART)==0)
-				error+="Missing part; ";
-			if ((item->state & UUFILE_NODATA)==0)
-				error+="No data; ";
+			QString error=i18n("Error(s): ");
+			if ((UUItem->state & UUFILE_MISPART)==0)
+				error+=i18n("Missing part; ");
+			if ((UUItem->state & UUFILE_NODATA)==0)
+				error+=i18n("No data; ");
 			dte->setError(error);
 			errorFlag=true;
 		}
 		
 			
 		//Try to decode anyway...
-		res = UUDecodeFile(item, NULL);
+		if (m_cancel) {
+			UUCleanUp();
+			if (dte)
+				delete dte;
+			return false;
+		}
+		res = UUDecodeFile(UUItem, NULL);
 		
 		end = QTime::currentTime();
 		kdDebug() << "Seconds used with UULib decoder: " << start.secsTo(end) << endl;
 		
 		
 		int j = 1;
-		QString origName=item->filename;
-		while (res == UURET_EXISTS) {
+		QString origName=UUItem->filename;
+		while (res == UURET_EXISTS & !m_cancel) {
 			//new name!
 			QString newName = origName + '.' + QString::number(j);
 			j++;
-			UURenameFile(item, (char*) newName.latin1());
-			res=UUDecodeFile(item, NULL);
+			UURenameFile(UUItem, (char*) newName.latin1());
+			res=UUDecodeFile(UUItem, NULL);
 			
 		}
+		if (m_cancel) {
+			UUCleanUp();
+			if (dte)
+				delete dte;
+			return false;
+		}
+		
 		if ( res != UURET_OK) {
 			
 			
 			if (res == UURET_IOERR) {
 				//Write error...disk full?
-				qDebug("Write error during decode");
+				kdDebug() << "Write error during decode\n";
 				//Forgot to put "diskerr" to "yes"
 				dte=new DecodeThreadEvent(false, postItem, true);
-				dte->setFileName(item->filename);
-				dte->setError("Write error!");
+				dte->setFileName(UUItem->filename);
+				dte->setError(i18n("Write error!"));
 				QApplication::postEvent(parent, dte);
 				return false;
 				
 			} else if (!errorFlag) {
 				dte=new DecodeThreadEvent(false, postItem);
 				dte->setError(UUstrerror(res));
-				dte->setFileName(item->filename);
+				dte->setFileName(UUItem->filename);
 			}
 
 			
@@ -717,7 +834,7 @@ bool DecodeThread::decode(QPostItem *postItem )
 			if (!errorFlag) {
 // 				qDebug("Successfully decoded %s", item->filename);
 				dte=new DecodeThreadEvent(true, postItem);
-				dte->setFileName(item->filename);
+				dte->setFileName(UUItem->filename);
 				
 			}
 			
@@ -729,7 +846,7 @@ bool DecodeThread::decode(QPostItem *postItem )
 		//No file do decode (rare, but it happens)
 // 		qDebug("No data");
 		dte=new DecodeThreadEvent(false, postItem);
-		dte->setError("No data to decode");
+		dte->setError(i18n("No data to decode"));
 		dte->setFileName("");
 	}
 	
@@ -827,15 +944,15 @@ int QUpdItem::error( int partId, QString & error )
 	partsToDo--;
 	failedParts++;
 	workingThreads--;
-	parts[partId]->listItem->setText(2, "Failed");
+	parts[partId]->listItem->setText(2, i18n("Failed"));
 	parts[partId]->listItem->setText(3, error);
 	parts[partId]->job->ng->stopUpdating();
 	if (partsToDo == 0) {
-		listItem->setText(2, "Finished!");
+		listItem->setText(2, i18n("Finished!"));
 		status=QItem::Finished_Item;
 		return QItem::Finished;
 	} else {
-		listItem->setText(2, "Queued");
+		listItem->setText(2, i18n("Queued"));
 		return QItem::Continue;
 	}
 		
@@ -845,7 +962,7 @@ int QUpdItem::error( int partId, QString & error )
 }
 int QListItem::error( int partId, QString & error )
 {
-	qDebug("QListItem::error");
+	kdDebug() << "QListItem::error\n";
 	parts[partId]->status=QItem::Failed_Part;
 // 	parts[partId]->job->status=Job::Failed_Job;
 	partsToDo--;
@@ -855,11 +972,11 @@ int QListItem::error( int partId, QString & error )
 	parts[partId]->listItem->setText(3, error);
 // 	parts[partId]->job->ag->stopUpdating();
 	if (partsToDo == 0) {
-		listItem->setText(2, "Finished");
+		listItem->setText(2, i18n("Finished"));
 		status=QItem::Finished_Item;
 		return QItem::Finished;
 	} else {
-		listItem->setText(2, "Queued");
+		listItem->setText(2, i18n("Queued"));
 		return QItem::Continue;
 	}
 }
@@ -868,13 +985,13 @@ void QPostItem::comError( int partId )
 {
 	parts[partId]->status=QItem::Queued_Part;
 	workingThreads--;
-	parts[partId]->listItem->setText(2, "Queued");
+	parts[partId]->listItem->setText(2, i18n("Queued"));
 	parts[partId]->listItem->setText(3, "");
 	if (workingThreads == 0)   {
-		listItem->setText(2, "Queued");
+		listItem->setText(2, i18n("Queued"));
 		etaTimer->stop();
 	}
-	else listItem->setText(2, "Processing (" + QString::number(workingThreads) + ")");
+	else listItem->setText(2, i18n("Processing (") + QString::number(workingThreads) + ")");
 }
 
 
@@ -893,23 +1010,22 @@ int QPostItem::error( int partId, QString & error )
 	//check if there are other parts
 	workingThreads--;
 	if (workingThreads == 0)   {
-			listItem->setText(2, "Queued");
-			etaTimer->stop();
-		}
-		else listItem->setText(2, "Processing (" + QString::number(workingThreads) + ")");
+		listItem->setText(2, i18n("Queued"));
+		etaTimer->stop();
+	} else listItem->setText(2, i18n("Processing (") + QString::number(workingThreads) + ")");
 	if (post->partNum[partId].count() != 0) {
 		//Yes, requeue me
 		return QItem::RequeMe;
 	} else {
 		partsToDo--;
 		failedParts++;
-		parts[partId]->listItem->setText(2, "Failed");
+		parts[partId]->listItem->setText(2, i18n("Failed"));
 		parts[partId]->listItem->setText(3, error);
 		//No, check if this was the last part...
 		if (partsToDo == 0) {
 			//last part, remove from queue
 			status=QItem::Finished_Item;
-			listItem->setText(2, "Decoding");
+			listItem->setText(2, i18n("Waiting for decoding..."));
 			listItem->setText(3, "");
 			etaTimer->stop();
 			delete etaTimer;
@@ -1045,6 +1161,7 @@ void QUpdItem::stopUpdateDb( int partId )
 
 void QUpdItem::downloadFinished( int partId )
 {
+	
 	parts[partId]->listItem->setText(2, "Waiting for db update");
 	parts[partId]->listItem->setText(3, "");
 }
@@ -1187,7 +1304,7 @@ Decoder * SelfDecodeThread::getDecoderForPost(QStringList posts) {
 					//We want everything after "begin 644 "
 					QString fName = line.stripWhiteSpace().mid(10);
 					kdDebug() << "Checking existance of " << destDir+fName << endl;
-					if (!overWrite && QFile::exists(destDir + fName)) {
+					if (!m_overWrite && QFile::exists(destDir + fName)) {
 						kdDebug() << "File exists!\n";
 						//rename the file
 						int i = 1;
@@ -1209,7 +1326,7 @@ Decoder * SelfDecodeThread::getDecoderForPost(QStringList posts) {
 					kdDebug() << "yyenc post found\n";
 					int namePos = line.find("name=");
 					QString fName = line.right(line.length()-namePos-5);
-					if (!overWrite && QFile::exists(destDir + fName)) {
+					if (!m_overWrite && QFile::exists(destDir + fName)) {
 						int i = 1;
 						while (QFile::exists(destDir + fName + '.' + QString::number(i)) )
 							i++;
@@ -1237,27 +1354,13 @@ Decoder * SelfDecodeThread::getDecoderForPost(QStringList posts) {
 }
 
 
-void SelfDecodeThread::run( )
-{
-// 	kdDebug() << "Starting decode thread...\n";
-	while(!items->isEmpty()) {
-		item=items->first();
-		if ( item &&  decode(item )) {
-			listLock->lock();
-			items->remove(items->first());
-			listLock->unlock();
-			item=0;
-		} else break;
-
-	}
-// 	kdDebug() << "Exiting decode thread...\n";
-	
-}
 
 bool SelfDecodeThread::decode( QPostItem *postItem )
 {
 	
-	DecodeThreadEvent *dte=0;;
+	DecodeThreadEvent *dte=0;
+	dte = new DecodeThreadEvent(postItem, DecodeThreadEvent::Dte_Start);
+	QApplication::postEvent(parent, dte);
 	QTime start, end;
 	start=QTime::currentTime();
 	QStringList partList;
@@ -1266,6 +1369,7 @@ bool SelfDecodeThread::decode( QPostItem *postItem )
 	QString errorString=QString::null;
 	QMap<int, Part *>::iterator pit;
 	parts = 0;
+	int progress = 0;
 	
 	//Build a QStringList of filenames (with path)
 	for (pit=postItem->parts.begin(); pit != postItem->parts.end(); ++pit) {
@@ -1276,9 +1380,11 @@ bool SelfDecodeThread::decode( QPostItem *postItem )
 	destDir=postItem->getSavePath();
 	
  	decoder=getDecoderForPost(partList);
-	
+	int doneParts = 0;
 	if (decoder!=NULL) {
-		while (!diskError && !decoder->decodingComplete()) {
+		while (!m_cancel && !diskError && !decoder->decodingComplete()) {
+			doneParts++;
+// 			sleep(1);
 			switch (decoder->decodeNextPart()) {
 				case Decoder::Err_BadCRC:
 					//bad crc in part
@@ -1307,9 +1413,14 @@ bool SelfDecodeThread::decode( QPostItem *postItem )
 				
 // 				
 			}
+			dte = new DecodeThreadEvent(postItem, DecodeThreadEvent::Dte_Progress);
+			progress = (int)(((float)doneParts/(float) parts)*100);
+			dte->setProgress(progress);
+			QApplication::postEvent(parent, dte);
+			
 				
 		}
-		if (!decoder->isSizeCorrect()) {
+		if (!m_cancel && !decoder->isSizeCorrect()) {
 			//Error: size is wrong.
 			//This can happen because there are some missing parts in the post.
 			errorFlag=true;
@@ -1341,8 +1452,15 @@ bool SelfDecodeThread::decode( QPostItem *postItem )
 	}*/
 	end = QTime::currentTime();
 	kdDebug() << "Seconds used for decoding with knzb decoder: " << start.secsTo(end) << endl;
-	
-	if (errorFlag && !diskError) {
+	if (m_cancel) {
+		kdDebug() << "Canceled decoding\n";
+		kdDebug() << "Deleting partial file: " << destDir + '/' + decoder->encodedFilename() << endl;
+// 		dte = new DecodeThreadEvent(postItem, DecodeThreadEvent::Dte_Canceled);
+		//Remove partial file
+		if (decoder)
+			QFile::remove(destDir + '/' + decoder->encodedFilename());
+		return false;
+	} else if (errorFlag && !diskError) {
 		kdDebug() << "Error (but not a diskError)\n";
 		dte=new DecodeThreadEvent(false, postItem);
 		if (decoder)
@@ -1354,14 +1472,14 @@ bool SelfDecodeThread::decode( QPostItem *postItem )
 		dte->setError(errorString);
 		
 	} else {
-		kdDebug() << "Else :)\n";
 		dte = new DecodeThreadEvent(true, postItem);
 		dte->setFileName(decoder->encodedFilename());
 	}
 	if (decoder)
 		delete decoder;
+	kdDebug() << "Posting decoder event\n";
 	QApplication::postEvent(parent, dte);
-	qDebug("Posting decoder event");
+	
 	if (diskError)
 		return false;
 	else return true;
@@ -1375,6 +1493,7 @@ DecoderThread::DecoderThread(QWidget *p, QMutex *mutex, QValueList<QPostItem*> *
 	parent=p;
 	items=decodeList;
 	listLock=mutex;
+	m_cancel = false;
 }
 
 /*
@@ -1488,7 +1607,7 @@ bool SaveQThread::processItem( QSaveItem *qsi )
 			return updateItem(qsi);
 			break;
 		default:
-			qDebug("Error: wrong QSaveItem type");
+			kdDebug() << "Error: wrong QSaveItem type\n";
 			return false;
 			break;
 	}
@@ -1529,7 +1648,7 @@ bool SaveQThread::delSaveItem( int id )
 	
 	
 	if (saveQDb->del(0, &key,0) != 0) {
-		qDebug("Error deleting key from db");
+		kdDebug() << "Error deleting key from db\n";
 		return false;
 	} else {
 		saveQDb->sync(0);
@@ -1650,6 +1769,47 @@ char * SaveQThread::retrieve( char * i, QString & s )
 
 
 
+int DecoderThread::cancel( int qID )
+{
+	DecodeThreadEvent *dte = 0;
+	listLock->lock();
+	//Check if we're canceling the currently decoding item
+	kdDebug() << "Currently decondig: " << item->qItemId << endl;
+	if (item->qItemId == qID) {
+		m_cancel = true;
+		dte = new DecodeThreadEvent(item, DecodeThreadEvent::Dte_Canceling);
+		
+	} else {
+		//Sync cancel...
+		QValueList<QPostItem*>::iterator it;
+		for( it = items->begin() ; it != items->end() ; ++it ){
+			if( (*it)->qItemId == qID ){
+				//Cancel item
+				items->remove(it);
+				//send a message to the QMgr saying we canceled the item
+				dte = new DecodeThreadEvent(*it, DecodeThreadEvent::Dte_Canceled);
+				break;
+				
+			}
+		}
+		
+	}
+	listLock->unlock();
+	/*
+	if (m_cancel)
+		return 0; //Asynccancel
+	else return qID; //Item canceled
+	*/
+	QApplication::postEvent(parent, dte);
+	return 0;
+}
+
+DecodeThread::~ DecodeThread( )
+{
+	delete uu;
+}
+
+
 
 
 
