@@ -49,6 +49,16 @@ enum QItemType {UpdItem=0, ArtItem=1, PostItem=2};
 
 class QPostItem;
 
+
+//Very ugly, but cannoy pass objects to UULibs busy callback
+struct UUCallBack
+{
+	volatile bool *cancel;
+	QWidget *parent;
+	QPostItem *item;
+	
+};
+
 class DecodeThreadEvent : public QCustomEvent {
 
 	friend class QMgr;
@@ -60,14 +70,20 @@ private:
 	QPostItem *item;
 	QString error;
 	QString fileName;
-	bool diskErr;	
+	bool diskErr;
+	short progress;
+	short event;
 	
 public:
-	
+	enum DteMessage { Dte_Progress, Dte_End, Dte_Canceled, Dte_Canceling, Dte_Start };
 	DecodeThreadEvent(bool b, QPostItem* i, bool de=false) : QCustomEvent(DECODETHREADEVENT) , ok(b), item(i), 
-			diskErr(de) {};
+	diskErr(de), event(Dte_End) {};
+	DecodeThreadEvent(QPostItem* i, short prog) : QCustomEvent(DECODETHREADEVENT),  item(i), progress(prog), event(Dte_Progress) {};
+	DecodeThreadEvent(QPostItem *i, DteMessage m) : QCustomEvent(DECODETHREADEVENT), item(i), event(m) {};
 	void setError(const char *e) {error=e;};
 	void setFileName(QString fn) {fileName=fn;};
+	void setProgress(int p) {progress = p;}
+	short getProgress() {return progress;}
 		
 };
 
@@ -75,21 +91,25 @@ public:
 
 class DecoderThread: public QThread {
 	protected:
-
 		QValueList<QPostItem*> *items;
-		bool overWrite; //if false, rename
-
+		bool m_overWrite; //if false, rename
+		bool m_cancel;
 		QMutex *listLock;
 		//True = continue, false = stop (fatal error, i.e. disk full)
 		virtual bool decode(QPostItem*)=0;
+
+		
 		QWidget *parent; //where to send decoding messages
 		QPostItem* item;	
 
 		
 	public:
 		DecoderThread(QWidget *, QMutex*, QValueList<QPostItem*>*);
-		virtual void setOverWrite(bool o)=0;
-		
+		void setOverWrite(bool o) {m_overWrite=o;}
+		bool getCancel() {return m_cancel;}
+		QPostItem *getItem () {return item;}
+		QWidget *getParent() {return parent;}
+		virtual int cancel(int qId);
 	
 };
 
@@ -97,11 +117,14 @@ class DecodeThread : virtual public DecoderThread {
 
 	protected:
 		virtual bool decode(QPostItem*);
+		UUCallBack *uu;
+// 		static int busyCallback(void *opaque, uuprogress *uuprog);
 	public:
 		DecodeThread(QWidget *, QMutex*, QValueList<QPostItem*>*);
-		void setOverWrite(bool o) {overWrite=o;}
+		virtual ~DecodeThread();
 		virtual void run();
 		
+		
 
 		
 		
@@ -118,7 +141,6 @@ class SelfDecodeThread : virtual public DecoderThread {
 	public:
 		SelfDecodeThread(QWidget *, QMutex*, QValueList<QPostItem*>*);
 		virtual void run();
-		void setOverWrite(bool o) {overWrite=o;}
 };
 
 class NntpThreadSocket;
@@ -296,12 +318,14 @@ class QItem :public QObject{
 	friend class QMgr;
 	friend class DecodeThread;
 	friend class SelfDecodeThread;
+	friend class DecoderThread;
 	friend class NntpThreadSocket;
 protected:
 	enum PartStatus {Finished_Part=0, Processing_Part=1, Failed_Part=2, Queued_Part=3, Canceled_Part, Paused_Part, Requeue_Part};
 	enum ItemStatus {Finished_Item=0, Processing_Item=1, Failed_Item=2, Queued_Item=3, Canceled_Item, Paused_Item};
 	enum OnError { Continue, Finished, RequeMe };
 	int qItemId; //id of this item
+	volatile bool processing;
 	int type;	//type of item
 	int status;	//status of the whole item
 	int partsToDo;
@@ -419,6 +443,8 @@ class QPostItem :public QItem {
 		bool over() {return overwriteExisting;};
 		bool dFailed() {return deleteFailed;};
 		void setTotalLines (uint tl) {totalPostLines=tl;}
+		void updateDecodingProgress(int prog);
+		void startDecoding();
 		
 		
 		QString getFName() {return rootFName;};
