@@ -118,16 +118,21 @@ void ServersList::slotSpeedChanged( int serverId, int threadId, int speed )
 
 void ServersList::slotThreadStart( int serverId, int threadId)
 {
+	
 	SpeedThread *sp=serverThreads[serverId][threadId];
-	sp->item->setText(StatusCol, "Working...");
-	sp->item->setText(SpeedCol, "0 KB/s");
-	sp->status=Running;
-// 	qDebug("WorkingThread: %d", (*servers)[serverId]->workingThreads);
-// 	qDebug("WorkingThread: %d", (*servers)[serverId]->workingThreads);
-	(*servers)[serverId]->workingThreads++;
-	qDebug("%d, %d: slotThreadStart(); workingThreads: %d", serverId, threadId, (*servers)[serverId]->workingThreads);
-	if (!serverSpeedTimer->isActive())
-		serverSpeedTimer->start(SPEED_TIMEOUT);
+	
+	if (sp->status != Running) {
+		sp->item->setText(StatusCol, i18n("Working..."));
+		sp->item->setText(SpeedCol, "0 KB/s");
+		sp->status=Running;
+	// 	qDebug("WorkingThread: %d", (*servers)[serverId]->workingThreads);
+	// 	qDebug("WorkingThread: %d", (*servers)[serverId]->workingThreads);
+		(*servers)[serverId]->workingThreads++;
+		kdDebug() << serverId << "," <<  threadId << ": slotThreadStart( ); workingThreads: " << (*servers)[serverId]->workingThreads << endl;
+	// 	qDebug("%d, %d: slotThreadStart(); workingThreads: %d", serverId, threadId, (*servers)[serverId]->workingThreads);
+		if (!serverSpeedTimer->isActive())
+			serverSpeedTimer->start(SPEED_TIMEOUT);
+	} //else I already started this thread...
 
 	
 // 	serverThreads[serverId][threadId]->setText(StatusCol, "Working...");
@@ -136,9 +141,10 @@ void ServersList::slotThreadStart( int serverId, int threadId)
 
 void ServersList::slotThreadStop( int serverId, int threadId)
 {
-	qDebug("%d, %d: SlotThreadStop", serverId, threadId);
+// 	qDebug("%d, %d: SlotThreadStop", serverId, threadId);
+	kdDebug() << serverId << "," << threadId << ": slotThreadStop()" << endl;
 	SpeedThread *sp=serverThreads[serverId][threadId];
-	sp->item->setText(StatusCol, "Idle");
+	sp->item->setText(StatusCol, i18n("Idle"));
 	sp->item->setText(SpeedCol, "");
 	sp->count=1;
 	sp->speed=0;
@@ -158,8 +164,8 @@ void ServersList::slotThreadPaused( int serverId, int threadId , int seconds)
 {
 	SpeedThread *sp=serverThreads[serverId][threadId];
 	if (seconds == 0)
-		sp->item->setText(StatusCol, "Paused");
-	else sp->item->setText(StatusCol, "Paused " + QString::number(seconds) + " s");
+		sp->item->setText(StatusCol, i18n("Paused"));
+	else sp->item->setText(StatusCol, i18n("Paused ") + QString::number(seconds) + " s");
  	sp->item->setText(SpeedCol, "");
 	sp->count=1;
 	sp->speed=0;
@@ -180,9 +186,10 @@ void ServersList::slotCountDown( int serverId, int threadId, int seconds)
 
 void ServersList::slotCanceling( int serverId, int threadId)
 {
-	qDebug("slotCanceling()");
+// 	qDebug("slotCanceling()");
+	kdDebug() << "slotCanceling( )" << endl;
 	SpeedThread *sp=serverThreads[serverId][threadId];
-	sp->item->setText(StatusCol, "Canceling...");
+	sp->item->setText(StatusCol, i18n("Canceling..."));
 	sp->item->setText(SpeedCol, "");
 	sp->count=1;
 	sp->speed=0;
@@ -193,17 +200,21 @@ void ServersList::slotCanceling( int serverId, int threadId)
 
 void ServersList::slotThreadDisconnect( int serverId , int threadId)
 {
-	qDebug("%d,%d: SlotThreadDisconnected()",serverId, threadId );
+// 	qDebug("%d,%d: SlotThreadDisconnected()",serverId, threadId );
+	kdDebug() << serverId << ", " << threadId << ": slotThreadDisconnect( )" << endl;
 	SpeedThread *sp=serverThreads[serverId][threadId];
-	sp->item->setText(StatusCol, "Disconnected");
+	sp->item->setText(StatusCol, i18n("Disconnected"));
 	sp->item->setText(SpeedCol, "");
 	sp->count=1;
 	sp->speed=0;
 // 	sp->status=Canceling;
-	qDebug("Status: %d", sp->status);
-	qDebug("WorkingThreads: %d", (*servers)[serverId]->workingThreads);
+// 	qDebug("Status: %d", sp->status);
+	kdDebug() << "Status: " << sp->status << endl;
+// 	qDebug("WorkingThreads: %d", (*servers)[serverId]->workingThreads);
+	kdDebug() << "WorkingThreads: " << (*servers)[serverId]->workingThreads << endl;
 	if (sp->status != Idle && sp->status != Stopped && sp->status != Paused) {
-		qDebug("Decrementing thread count");
+// 		qDebug("Decrementing thread count");
+		kdDebug() << "Decrementing thread count\n";
 		((*servers)[serverId]->workingThreads)--;
 		sp->status = Stopped;
 	}
@@ -233,7 +244,8 @@ void ServersList::slotAddServer( NntpHost *nh )
 	int id=0;
 	while (servers->contains(++id));
 	nh->id=id;
-	qDebug("slotAddServer(): Id: %d", id);
+// 	qDebug("slotAddServer(): Id: %d", id);
+	kdDebug() << "slotAddServer(): id: " << id << endl;
 	(*servers)[id]=nh;
 	m_saveServer(nh);
 	m_addServer((*servers)[id]);
@@ -379,7 +391,8 @@ void ServersList::m_loadServers( )
 {
 	serverDb = new Db(dbEnv, 0);
 	if (serverDb->open(NULL, serversDbName.latin1() , NULL, DB_BTREE, DB_CREATE | DB_THREAD , 0644) != 0)
-		qDebug("Error opening servers db");
+		kdDebug() << "Error opening servers db\n";
+// 		qDebug("Error opening servers db");
 	
 	char datamem[10000];
 	char keymem[10000];
@@ -429,8 +442,8 @@ void ServersList::m_saveServer( NntpHost* nh)
 	key.set_size(sizeof(int));
 	int ret=serverDb->put(0, &key,&data, 0);
 	if (ret != 0)
-		qDebug("Error saving server: %d", ret);
-	else qDebug("server id %d saved", nh->id);
+		kdDebug() << "Error saving server: " << ret << endl;
+	else kdDebug() << "Server saved: " << nh->id << endl;
 	serverDb->sync(0);
 		
 	
@@ -438,7 +451,8 @@ void ServersList::m_saveServer( NntpHost* nh)
 
 void ServersList::slotDeleteServer( )
 {
-	qDebug("Delete server");
+// 	qDebug("Delete server");
+	kdDebug() << "Delete server\n";
 	KListViewItem* selected=(KListViewItem*)m_serversList->selectedItem();
 	if (!selected)
 		return;
@@ -472,8 +486,8 @@ void ServersList::slotDeleteServer( )
 	key.set_data(&serverId);
 	key.set_size(sizeof(serverId));
 	if ((serverDb->del(NULL, &key, 0)) != 0)
-		qDebug("Error deleting server!");
-	else qDebug("Server id %d deleted", serverId);
+		kdDebug() << "Error deleting server\n";
+	else kdDebug() << "Server " << serverId << " deleted\n";
 	if (servers->isEmpty())
 		emit sigHaveServers(false);
 	
@@ -795,8 +809,11 @@ void ServersList::slotServerSpeedTimeout( )
 			ThreadView tv = serverThreads[sit.key()];
 			serverSpeed = 0;
 			for (it = tv.begin(); it != tv.end() ; ++it) {
+// 				kdDebug() << "Thread speed: " << it.data()->speed << endl;
 				serverSpeed += it.data()->speed;
 			}
+// 			kdDebug() << "severSpeed: " << serverSpeed << endl;
+// 			kdDebug() << "sit.data()->speed: " << sit.data()->speed << endl;
 			serverSpeed = (serverSpeed+sit.data()->speed)/2;
 			sit.data()->item->setText(SpeedCol, QString::number( serverSpeed ) + " KB/s");
 			sit.data()->speed=serverSpeed;
