@@ -29,7 +29,7 @@
 
 void UpdateDbThread::run() {
 
-// 	qDebug("UpdateDbThread::run(): Items in queue: %d", jobList->count() );
+// 	("UpdateDbThread::run(): Items in queue: %d", jobList->count() );
 	
 	while(!jobList->isEmpty()) {
 		listLock->lock();
@@ -42,6 +42,15 @@ void UpdateDbThread::run() {
 			listLock->unlock();
 			e = new UpdateDbThreadEvent(job, UpdateDbThreadEvent::UpDb_stopUpd);
 			QApplication::postEvent(parent, e);
+		} else if (m_cancel) {
+			kdDebug() << "Canceled group update\n";
+			e = new UpdateDbThreadEvent(job, UpdateDbThreadEvent::UpDb_Canceled);
+			listLock->lock();
+			jobList->remove(jobList->first());
+			m_cancel = false;
+			listLock->unlock();
+			QApplication::postEvent(parent, e);
+			
 		} else {
 			// Db error...
 			listLock->lock();
@@ -73,7 +82,7 @@ bool UpdateDbThread::expire( NewsGroup * ng, int hostId) {
 	uint progress=groupArticles;
 
 	if ((ng->getDb()->cursor(0, &cursor, DB_WRITECURSOR))!= 0) {
-		qDebug("Error creating cursor!!");
+		kdDebug() << "Error creating cursor!!\n";
 		//Set the error!
 		return false;
 	}
@@ -88,10 +97,10 @@ bool UpdateDbThread::expire( NewsGroup * ng, int hostId) {
 	memset(&key, 0, sizeof(key));
 	key.set_flags(DB_DBT_MALLOC);
 	
-
+	QTime start = QTime::currentTime();
+	kdDebug() << "Expire starting at " << start.toString() << endl;	
 	
-	
-	while((ret=cursor->get(&key, &data, DB_NEXT)) == 0) {
+	while(!m_cancel && (ret=cursor->get(&key, &data, DB_NEXT)) == 0) {
 		
 			
 		count++;
@@ -111,7 +120,7 @@ bool UpdateDbThread::expire( NewsGroup * ng, int hostId) {
 					unreadArticles--;
 				case BinHeader::Delete_Read:
 					if ((ret=cursor->del(0))!=0)
-						qDebug("Error deleting from db: %d", ret);
+						kdDebug() << "Error deleting from db: " << ret << endl;
 					else groupArticles--;
 	// 				memset(&data, 0, sizeof(data));
 	// 				data.set_flags(DB_DBT_MALLOC);
@@ -125,7 +134,7 @@ bool UpdateDbThread::expire( NewsGroup * ng, int hostId) {
 					data.set_size(bh->getRecordSize());
 					
 					if ((ret=cursor->put(&key, &data, DB_CURRENT))!=0) 
-						qDebug("Error updating post: %d", ret);
+						kdDebug() << "Error updating post: " <<  ret << endl;
 					// 			else qDebug("Error! %d", ret);
 					delete p;
 					break;
@@ -147,7 +156,7 @@ bool UpdateDbThread::expire( NewsGroup * ng, int hostId) {
 		
 		
 		if (ret != 0) {
-			qDebug("Error while expiring...");
+			kdDebug() << "Error while expiring...\n";
 			return false;
 		}
 		
@@ -159,17 +168,20 @@ bool UpdateDbThread::expire( NewsGroup * ng, int hostId) {
 			
 		}
 		
-	} 
+	}
+	kdDebug() << "Expire finished. Seconds: " << start.secsTo(QTime::currentTime()) << endl;
+	if (cursor->close() != 0)
+		kdDebug() << "Error closing cursor!\n";
+	
+	if (m_cancel)
+		return false;
 	
 	if (ret != DB_NOTFOUND) {
-		qDebug("Exited from cursor cycle with strange error %d", ret);
+		kdDebug() << "Exited from cursor cycle with strange error " << ret << endl;
 		return false;
 	}
 	
-
-    // Begin pasted code
-    if (cursor->close() != 0)
-		qDebug("Error closing cursor!");
+    
 
 	return true;
 //     qDebug("Elements in DB: %d", count);
@@ -184,14 +196,18 @@ bool UpdateDbThread::update()
 // 	qDebug("Expiring");
 	e=new UpdateDbThreadEvent(job, UpdateDbThreadEvent::UpDb_startExp);
 	QApplication::postEvent(parent, e);
-	if (! expire(job->ng,job->qId))
+	if (! expire(job->ng,job->qId)) {
+		if (m_cancel)
+			QFile::remove(job->fName);	
 		return false;
+	}
 	e=new UpdateDbThreadEvent(job, UpdateDbThreadEvent::UpDb_startUpd);
 	QApplication::postEvent(parent, e);
 // 	qDebug("Expired");
 	Header *h;
-	int tret;
+
 	int lineProcessed=0;
+	int maxHeaderNum;
 	int totalLines=job->artSize;
 	headerFile=new QFile(job->fName);
 	cacheSize=0;
@@ -205,12 +221,12 @@ bool UpdateDbThread::update()
 		
 		
 		if (!headerFile->open(IO_ReadOnly)) {
-			qDebug("UpdateDbThread::update: Cannot open file %s", (const char *) job->fName);
+			kdDebug() << "UpdateDbThread::update: Cannot open file " << job->fName << endl;
 			return false;
 		} 
 		QTime previous, current;
 		previous=QTime::currentTime();
-		while ( (headerFile->readLine(line, 2000)) != -1 ) {
+		while (!m_cancel &&  (headerFile->readLine(line, 2000)) != -1 ) {
 			h=new Header(line);
 			
 			lineProcessed++;
@@ -226,13 +242,13 @@ bool UpdateDbThread::update()
 				if (dbBinHeaderPut(db, h, hostId) == false) 
 #endif
 				{
-					qDebug("Error inserting header!");
+					kdDebug() << "Error inserting header!\n";
 					return false;
 				
-				} else job->ng->high[hostId] = h->m_num;
+				} else maxHeaderNum = h->m_num;
 			} else kdDebug() << "Wrong header - maybe an incomplete line?\n";
-			
-			job->artSize=0;
+			//??????
+// 			job->artSize=0;
 			delete h;
 			
 			//DEBUG!!!
@@ -249,6 +265,7 @@ bool UpdateDbThread::update()
 				
 			
 		}
+		job->ng->high[hostId] = maxHeaderNum;
 		cacheFlush(db);
 		db->sync(0);
 	} else kdDebug() << "Empty headerFile!\n";
@@ -257,11 +274,25 @@ bool UpdateDbThread::update()
 	headerFile->close();
 	
 	if (!headerFile->remove()) 
-		qDebug("Error deleting file");
+		kdDebug() << "Error deleting file\n";
 	
 	delete headerFile;
+	if (m_cancel) {
+		saveGroup();
+		return false;
+	} else return saveGroup();
 	
 	
+	
+	
+	
+	
+	
+}
+
+bool UpdateDbThread::saveGroup()
+{
+	int tret;
 	Dbt groupkey, groupdata;
 	memset(&groupkey, 0, sizeof(groupkey));
 	memset(&groupdata, 0,  sizeof(groupdata));
@@ -274,7 +305,7 @@ bool UpdateDbThread::update()
 	groupkey.set_data((void*)tempkey);
 	groupkey.set_size(job->ng->ngName.length());
 	if ((tret=job->gdb->put(NULL, &groupkey, &groupdata, 0)) != 0) {
-		qDebug("Error updating newsgroup: %d", tret);
+		kdDebug() << "Error updating newsgroup: %d" << tret << endl;
 		delete tempng;
 		return false;
 	}
@@ -283,8 +314,6 @@ bool UpdateDbThread::update()
 	job->gdb->sync(0);
 	return true;
 	
-	
-	
 }
 
 BinHeader * UpdateDbThread::dbBinHeaderGet(Db *db, QString index) {
@@ -375,7 +404,7 @@ bool UpdateDbThread::cachePut( Db * db, Header * h, QString cIndex, int hostId )
 		bh->setStatus(BinHeader::bh_new);
 		
 		if (h->m_date.isNull()) {
-			qDebug("Date is null!!!");
+			kdDebug() << "Date is null!!!\n";
 
 		} else {
 			bh->setDate(createDateTime(QStringList::split(" ", h->m_date, true)));
@@ -436,7 +465,7 @@ bool UpdateDbThread::cacheFlush(Db* db, uint size )
 			key.set_size(cIndex.length());
 			ret=db->put(NULL, &key, &data, 0);
 			if (ret != 0) {
-				qDebug("Error flushing cache: %d", ret);
+				kdDebug() << "Error flushing cache: " << ret << endl;
 				return false;
 			}
 			free(data.get_data());
@@ -450,7 +479,7 @@ bool UpdateDbThread::cacheFlush(Db* db, uint size )
 	} else {
 		//Flush "size" elements, with a FIFO policy
 		if (size > cache.count()) {
-			qDebug("wrong flush size!");
+			kdDebug() << "wrong flush size!\n";
 			size=cache.count();
 		}
 			
@@ -466,7 +495,7 @@ bool UpdateDbThread::cacheFlush(Db* db, uint size )
 			key.set_size(cIndex.length());
 			ret=db->put(NULL, &key, &data, 0);
 			if (ret != 0) {
-				qDebug("Error flushing cache: %d", ret);
+				kdDebug() << "Error flushing cache: " <<  ret << endl;
 				return false;
 			}else {
 				//Remove item from the cache
@@ -541,7 +570,7 @@ int UpdateDbThread::dbHeaderPut( Db * db, Header * h, int hostId ) {
 					data.set_size(bh->getRecordSize());
 					data.set_data(p);
 					if ((ret=db->put(NULL, &key, &data, 0)) != 0) {
-						qDebug("Error inserting header");
+						kdDebug() << "Error inserting header\n";
 					}
 					// 					qDebug("Updated header inserted");
 					// 				else qDebug("Error updating record");
@@ -582,7 +611,7 @@ int UpdateDbThread::dbHeaderPut( Db * db, Header * h, int hostId ) {
 
 
             if (h->m_date.isNull()) {
-                qDebug("Date is null!!!");
+				kdDebug() << "Date is null!!!\n";
                 // 				qDebug("Header: %s", (const char *) h->m_subj);
                 // 				qDebug("Number: %s", (const char *) h->m_num);
             } else
@@ -644,20 +673,18 @@ UpdateDbThread::UpdateDbThread( QWidget *w, QMutex *lock, QValueList< Job * > *j
 	cache.resize(CACHESIZE);
 	cache.setAutoDelete(true);
 	rx.setPattern("\\((\\d+)/(\\d+)\\)");
+	m_cancel = false;
 	
 	
 }
 
-QString UpdateDbThread::createDateTime( QStringList dateTime) {
+uint UpdateDbThread::createDateTime( QStringList dateTime) {
 
     int i=(dateTime[0].at(dateTime[0].length()-1) == ',') ? 1:0;
     QDate d=QDate::fromString(" " + dateTime[i+1] + " " + dateTime[i] +" " + dateTime[i+2]);
     QTime t=QTime::fromString(dateTime[i+3]);
     QDateTime dt(d, t);
-	
-
-
-    return dt.toString();
+    return dt.toTime_t();
 
 
 }
@@ -686,6 +713,31 @@ bool UpdateDbThread::hasToBeExpired( int hostId, int lw, char * p )
 	
 }
 
+int UpdateDbThread::cancel( int jID )
+{
+	UpdateDbThreadEvent *ude = 0;	
+	listLock->lock();
+	if (job->id == jID) {
+		m_cancel = true;
+		ude = new UpdateDbThreadEvent(job, UpdateDbThreadEvent::UpDb_Canceling);
+		
+	} else {
+		QValueList<Job*>::iterator it;
+		for (it = jobList->begin(); it != jobList->end(); ++it) {
+			if ( (*it)->id == jID) {
+				jobList->remove(it);
+				ude = new UpdateDbThreadEvent(*it, UpdateDbThreadEvent::UpDb_Canceled);
+				break;
+			}
+		}
+	}
+	listLock->unlock();
+	QApplication::postEvent(parent, ude);
+	return 0;
+	
+}
+
+
 #if INDEXDB_VERSION != 0
 
 SIndex * UpdateDbThread::getSIndex( Db * sdb, int artNum )
@@ -730,7 +782,7 @@ bool UpdateDbThread::writeSIndex( Db * sdb, int artNum, SIndex * sindex )
 	if (ret == 0)
 		return true;
 	else {
-		qDebug("Cannot write secondary index: %d", ret);
+		kdDebug() << "Cannot write secondary index: " <<  ret << endl;
 		return false;
 	}
 	
@@ -747,7 +799,7 @@ bool UpdateDbThread::delSIndex( Db * sdb, int partId )
 	if (ret == 0)
 		return true;
 	else {
-		qDebug("Cannot delete item from secondary index: %d", ret);
+		kdDebug() << "Cannot delete item from secondary index: " << ret << endl;
 		return false;
 	}
 	
@@ -828,7 +880,7 @@ bool UpdateDbThread::expireByNum( NewsGroup * ng, int hostId )
 				bh=dbBinHeaderGet(db, si->index);
 				if (bh == 0) {
 					//Error getting binheader...something's wrong!
-					qDebug("Errot getting binheader from db");
+					kdDebug() << "Errot getting binheader from db\n";
 					return false;
 				}
 				cache.insert(si->index, bh);
@@ -867,7 +919,7 @@ bool UpdateDbThread::expireByNum( NewsGroup * ng, int hostId )
 			
 		} else if (ret != DB_NOTFOUND) {
 			//Error reading db!
-			qDebug("Error getting secondary index: %d", ret);
+			kdDebug() << "Error getting secondary index: " << ret << endl;
 			return false;
 		}
 		current=QTime::currentTime();
@@ -889,5 +941,5 @@ bool UpdateDbThread::expireByNum( NewsGroup * ng, int hostId )
 	
 }
 
-#endif
+#endif //INDEXDB_VERSION
 
