@@ -51,7 +51,7 @@ class UpdateDbThreadEvent : public QCustomEvent {
 		int err;
 		
 	public:
-		enum UpDbMessages  { UpDb_startExp, UpDb_stopExp, UpDb_startUpd, UpDb_stopUpd,  UpDb_Working, UpDb_Err, UpDb_DiskErr };
+		enum UpDbMessages  { UpDb_startExp, UpDb_stopExp, UpDb_startUpd, UpDb_stopUpd,  UpDb_Working, UpDb_Err, UpDb_DiskErr, UpDb_Canceled, UpDb_Canceling };
 		UpdateDbThreadEvent(Job *_j, int t, int p=0, int tot=0) : QCustomEvent(UPDATEDBTHREADEVENT) , j(_j),  type(t) , partial(p), total(tot) {};
 	
 };
@@ -71,11 +71,12 @@ class UpdateDbThreadEvent : public QCustomEvent {
  	private:
 		bool expire(NewsGroup *ng, int hostId);
 		int dbHeaderPut(Db *db, Header*, int);
-		QString createDateTime( QStringList dateTime);
+		uint createDateTime( QStringList dateTime);
 		bool update();
 		BinHeader* dbBinHeaderGet(Db*db, QString index);
 		bool hasToBeExpired(int hostId, int lw, char* p);
-		
+		volatile bool m_cancel;
+		bool saveGroup();
 		
 		bool cacheFlush(Db* db, uint size=0);
 #if INDEXDB_VERSION != 0		
@@ -134,6 +135,7 @@ class UpdateDbThreadEvent : public QCustomEvent {
  	UpdateDbThread(QWidget *, QMutex*, QValueList<Job*>*);
 	virtual void run();
 	enum Error {Write_Err};
+	int cancel(int jID);
  
 };
 
